<?php 
/* 
 ----------------------------------------------------------------------
 GLPI - Gestionnaire Libre de Parc Informatique
 Copyright (C) 2003-2010 by the INDEPNET Development Team.
 
 http://indepnet.net/   http://glpi-project.org
 ----------------------------------------------------------------------

 LICENSE

 This file is part of GLPI.

 GLPI is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 2 of the License, or
 (at your option) any later version.

 GLPI is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with GLPI; if not, write to the Free Software
 Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 ------------------------------------------------------------------------
 */
//lt_LT

$LANG=array();


$LANG['backup'][0]="SQL išvestis"; 
$LANG['backup'][1]="XML išvestis"; 
$LANG['backup'][11]="Dydis"; 
$LANG['backup'][13]="Rodyti/Atsiųsti"; 
$LANG['backup'][16]="Pakeisti duomenų bazės duomenis iš rezervinės kopijos rinkmenos:"; 
$LANG['backup'][17]="Pašalinti šią rinkmeną"; 
$LANG['backup'][18]="Sukurti duomenų bazės rezervinę kopiją"; 
$LANG['backup'][19]="Dabar"; 
$LANG['backup'][21]="Tokia rinkmena jau yra"; 
$LANG['backup'][22]="Nerandama baito"; 
$LANG['backup'][23]="Mysql klaida, pradedant nuo"; 
$LANG['backup'][24]="Automatinis peradresavimas, arba spustelti"; 

$LANG['bookmark'][1]="skirtukas"; 
$LANG['bookmark'][2]="Dalinis skirtuko įkėlimas"; 
$LANG['bookmark'][3]="Nėra išsaugotų skirtukų"; 
$LANG['bookmark'][4]="Naujas skirtukas"; 
$LANG['bookmark'][5]="Vieši skirtukai"; 
$LANG['bookmark'][6]="Numatytasis rodymas"; 

$LANG['buttons'][0]="Paieška"; 
$LANG['buttons'][2]="Toliau"; 
$LANG['buttons'][3]="Associate"; 
$LANG['buttons'][4]="Įdiegti"; 
$LANG['buttons'][5]="Išdiegti"; 
$LANG['buttons'][6]="Šalinti"; 
$LANG['buttons'][7]="Atnaujinti"; 
$LANG['buttons'][8]="Pridėti"; 
$LANG['buttons'][9]="Prijungti"; 
$LANG['buttons'][10]="Atjungti"; 
$LANG['buttons'][11]="Kitas"; 
$LANG['buttons'][12]="Ankstesnis"; 
$LANG['buttons'][13]="Atgal"; 
$LANG['buttons'][14]="Atnaujinti"; 
$LANG['buttons'][15]="Kalendorius"; 
$LANG['buttons'][16]="Išvalyti"; 
$LANG['buttons'][17]="Invertuoti žymėjimą"; 
$LANG['buttons'][18]="Pažymėti visus"; 
$LANG['buttons'][19]="Atžymėti visus"; 
$LANG['buttons'][20]="Perkelti"; 
$LANG['buttons'][21]="Atkurti"; 
$LANG['buttons'][22]="Išvalyti"; 
$LANG['buttons'][23]="Rodyti"; 
$LANG['buttons'][24]="Aukštyn"; 
$LANG['buttons'][25]="Žemyn"; 
$LANG['buttons'][27]="Current page in PDF"; 
$LANG['buttons'][28]="Current page in SLK"; 
$LANG['buttons'][29]="All pages in PDF"; 
$LANG['buttons'][30]="All pages in SLK"; 
$LANG['buttons'][31]="Eksportas"; 
$LANG['buttons'][32]="Pabaiga"; 
$LANG['buttons'][33]="Pradžia"; 
$LANG['buttons'][34]="Atšaukti"; 
$LANG['buttons'][37]="Importas"; 
$LANG['buttons'][38]="Atrakinti"; 
$LANG['buttons'][39]="Pakeisti"; 
$LANG['buttons'][40]="Rodyti visus"; 
$LANG['buttons'][41]="Aktyvuoti"; 
$LANG['buttons'][42]="Deaktyvuoti"; 
$LANG['buttons'][43]="Naršyti"; 
$LANG['buttons'][44]="Current page in CSV"; 
$LANG['buttons'][45]="All pages in CSV"; 
$LANG['buttons'][46]="Ankstesni"; 
$LANG['buttons'][47]="Po"; 
$LANG['buttons'][48]="Perkelti"; 
$LANG['buttons'][49]="Išlaikyti"; 
$LANG['buttons'][50]="Tikrinti"; 
$LANG['buttons'][51]="Išsaugoti"; 
$LANG['buttons'][52]="Įkelti"; 
$LANG['buttons'][53]="Išvalyti"; 
$LANG['buttons'][55]="Pirmas"; 
$LANG['buttons'][56]="Paskutinis"; 
$LANG['buttons'][57]="Vykdyti"; 
$LANG['buttons'][58]="Atnaujinti"; 
$LANG['buttons'][59]="Atsieti"; 

$LANG['calendar'][0]="YYYY-MM-DD"; 
$LANG['calendar'][1]="DD-MM-YYYY"; 
$LANG['calendar'][2]="MM-DD-YYYY"; 

$LANG['calendarD'][0]="S"; 
$LANG['calendarD'][1]="P"; 
$LANG['calendarD'][2]="A"; 
$LANG['calendarD'][3]="T"; 
$LANG['calendarD'][4]="K"; 
$LANG['calendarD'][5]="Pn"; 
$LANG['calendarD'][6]="Š"; 

$LANG['calendarDay'][0]="Sekmadienis"; 
$LANG['calendarDay'][1]="Pirmadienis"; 
$LANG['calendarDay'][2]="Antradienis"; 
$LANG['calendarDay'][3]="Trečiadienis"; 
$LANG['calendarDay'][4]="Ketvirtadienis"; 
$LANG['calendarDay'][5]="Penktadienis"; 
$LANG['calendarDay'][6]="Šeštadienis"; 

$LANG['calendarM'][0]="Sausis"; 
$LANG['calendarM'][1]="Vasaris"; 
$LANG['calendarM'][2]="Kovas"; 
$LANG['calendarM'][3]="Balandis"; 
$LANG['calendarM'][4]="Gegužė"; 
$LANG['calendarM'][5]="Birželis"; 
$LANG['calendarM'][6]="Liepa"; 
$LANG['calendarM'][7]="Rugpjūtis"; 
$LANG['calendarM'][8]="Rugsėjis"; 
$LANG['calendarM'][9]="Spalis"; 
$LANG['calendarM'][10]="Lapkritis"; 
$LANG['calendarM'][11]="Gruodis"; 

$LANG['cartridges'][0]="Kasetė"; 
$LANG['cartridges'][7]="Kasetė nerasta"; 
$LANG['cartridges'][9]="Nėra kasetės"; 
$LANG['cartridges'][10]="Dažai"; 
$LANG['cartridges'][11]="Ink-Jet"; 
$LANG['cartridges'][12]="Kasetės tipas"; 
$LANG['cartridges'][13]="Naujas(i)"; 
$LANG['cartridges'][14]="Spausdintuve(uose)"; 
$LANG['cartridges'][15]="Naudota(os)"; 
$LANG['cartridges'][16]="Kasetės"; 
$LANG['cartridges'][20]="Naujas"; 
$LANG['cartridges'][21]="Spausdintuve"; 
$LANG['cartridges'][22]="Naudota"; 
$LANG['cartridges'][24]="Papildymo data"; 
$LANG['cartridges'][27]="Įdėtas į"; 
$LANG['cartridges'][29]="Termino pabaiga"; 
$LANG['cartridges'][32]="Suderinamų spausdintuvų modeliai"; 
$LANG['cartridges'][33]="Užpildytos kasetės"; 
$LANG['cartridges'][34]="Nėra laisvos kasetės"; 
$LANG['cartridges'][35]="Naudota(os) kasetė(s)"; 
$LANG['cartridges'][37]="Juosta"; 
$LANG['cartridges'][39]="Spausdintuvo skaitliukas"; 
$LANG['cartridges'][40]="Kiek laiko sandelyje"; 
$LANG['cartridges'][41]="Naudojimo laikas"; 
$LANG['cartridges'][42]="Atspausdintų puslapių skaičius"; 

$LANG['central'][2]="Vėliausi"; 
$LANG['central'][4]="Be pasikeitimų"; 
$LANG['central'][5]="Pradžia"; 
$LANG['central'][6]="Atsijungti"; 
$LANG['central'][7]="Pagalba"; 
$LANG['central'][8]="Papildymai"; 
$LANG['central'][9]="Vykdomos mano paraiškos"; 
$LANG['central'][10]="Naujos paraiškos"; 
$LANG['central'][12]="Asmeninis"; 
$LANG['central'][13]="Bendras"; 
$LANG['central'][14]="Grupės"; 
$LANG['central'][18]="Your tickets to close"; 
$LANG['central'][19]="Your tickets to validate"; 

$LANG['choice'][0]="Ne"; 
$LANG['choice'][1]="Taip"; 

$LANG['common'][0]="Be vardo"; 
$LANG['common'][1]="Elementas"; 
$LANG['common'][2]="ID"; 
$LANG['common'][3]="Show the trash"; 
$LANG['common'][4]="Web"; 
$LANG['common'][5]="Gamintojas"; 
$LANG['common'][6]="Formos vardas"; 
$LANG['common'][7]="Pasirinkite formą"; 
$LANG['common'][8]="Tvarkyti formas..."; 
$LANG['common'][9]="Įtraukti formą..."; 
$LANG['common'][10]="Aptarnaujantis darbuotojas"; 
$LANG['common'][11]="Su apribojimais"; 
$LANG['common'][12]="Sąranka"; 
$LANG['common'][13]="Forma"; 
$LANG['common'][14]="Formos"; 
$LANG['common'][15]="Patalpa"; 
$LANG['common'][16]="Vardas"; 
$LANG['common'][17]="Tipas"; 
$LANG['common'][18]="Alternate username"; 
$LANG['common'][19]="Serijos Nr."; 
$LANG['common'][20]="Inventoriaus nr."; 
$LANG['common'][21]="Alternate username number"; 
$LANG['common'][22]="Modelis"; 
$LANG['common'][23]="Operacija sėkminga"; 
$LANG['common'][24]="Nepažymėtas elementas ar neteisingai nurodyta operacija"; 
$LANG['common'][25]="Pastabos"; 
$LANG['common'][26]="Paskutinis pakeitimas"; 
$LANG['common'][27]="Data"; 
$LANG['common'][28]="Pašalintas"; 
$LANG['common'][29]="Papildiniai"; 
$LANG['common'][30]="Naujas elementas"; 
$LANG['common'][31]="Forma užpildymui"; 
$LANG['common'][32]="Savybės"; 
$LANG['common'][33]="Viso"; 
$LANG['common'][34]="Naudotojas"; 
$LANG['common'][35]="Grupė"; 
$LANG['common'][36]="Kategorija"; 
$LANG['common'][37]="Writer"; 
$LANG['common'][38]="Use unitary management"; 
$LANG['common'][39]="Dauginti šį elementą visiems esamiems prijungimams"; 
$LANG['common'][40]="Do you really want to use unitary management this item ?"; 
$LANG['common'][41]="Perspėjimai e-paštu"; 
$LANG['common'][42]="Mobile phone"; 
$LANG['common'][43]="Vardas"; 
$LANG['common'][44]="Numatytoji reikšmė(s)"; 
$LANG['common'][45]="MB max"; 
$LANG['common'][46]="Vcard"; 
$LANG['common'][47]="Eiga"; 
$LANG['common'][48]="Pavardė"; 
$LANG['common'][49]="Nėra"; 
$LANG['common'][50]="Confirm the final deletion ?"; 
$LANG['common'][51]="Pilnas vardas"; 
$LANG['common'][52]="Tarnybinė stotis"; 
$LANG['common'][53]="Sąrašas"; 
$LANG['common'][54]="Elementas nerastas"; 
$LANG['common'][55]="Tikrai norite pašalinti šį elementą?"; 
$LANG['common'][56]="Standard interface"; 
$LANG['common'][57]="Antraštė"; 
$LANG['common'][58]="Didžiausia reikšmė"; 
$LANG['common'][59]="Bendras"; 
$LANG['common'][60]="Aktyvus"; 
$LANG['common'][61]="Nenustatyta klaida"; 
$LANG['common'][62]="Kitas"; 
$LANG['common'][63]="Klaida(os)"; 
$LANG['common'][64]="Tvarkytojas"; 
$LANG['common'][65]="Sąsaja"; 
$LANG['common'][66]="Visi"; 
$LANG['common'][67]="Kiti"; 
$LANG['common'][68]="Gulsčias"; 
$LANG['common'][69]="Stačiai"; 
$LANG['common'][70]="Sėkmingai pridėta"; 
$LANG['common'][71]="Sėkmingai atnaujintas"; 
$LANG['common'][72]="Item successfully deleted"; 
$LANG['common'][73]="Item successfully purged"; 
$LANG['common'][74]="Sėkmingai atstatytas"; 
$LANG['common'][75]="Nėra teisių elementui kartotis šiame padalinyje"; 
$LANG['common'][76]="Bendras"; 
$LANG['common'][77]="Asmeninis"; 
$LANG['common'][78]="Nustatyti viešu"; 
$LANG['common'][79]="Set personal"; 
$LANG['common'][80]="Įkėlimas..."; 
$LANG['common'][81]="Don't show deleted items"; 
$LANG['common'][82]="MB"; 
$LANG['common'][83]="You don't have permission to perform this action."; 
$LANG['common'][84]="Keitimas negalimas, nes yra susietų elementų."; 
$LANG['common'][85]="Change visibility in the child entities"; 
$LANG['common'][86]="You are not allowed to change the visibility flag for child entities."; 
$LANG['common'][87]="Nauja kortelė"; 
$LANG['common'][88]="Personal"; 
$LANG['common'][89]="Not installed"; 
$LANG['common'][90]="Object"; 
$LANG['common'][91]="Can't change this attribute. It's inherited from its parent."; 
$LANG['common'][92]="Alternate username"; 
$LANG['common'][93]="New child heading"; 

$LANG['computers'][0]="Volume"; 
$LANG['computers'][1]="Free percentage"; 
$LANG['computers'][2]="Laisvos apimties"; 
$LANG['computers'][3]="Global size"; 
$LANG['computers'][4]="Rinkmenų išdėstymo sistema"; 
$LANG['computers'][5]="Mount point"; 
$LANG['computers'][6]="Partition"; 
$LANG['computers'][7]="Pridėti saugyklą"; 
$LANG['computers'][8]="Volumes"; 
$LANG['computers'][9]="Operating system"; 
$LANG['computers'][10]="Serial of the operating system"; 
$LANG['computers'][11]="Product ID of the operating system"; 
$LANG['computers'][14]="Įterptas"; 
$LANG['computers'][23]="Type of memory"; 
$LANG['computers'][24]="Memory (MB)"; 
$LANG['computers'][25]="Hard drive size"; 
$LANG['computers'][36]="Hard drive type"; 
$LANG['computers'][37]="Nėra prijungtų vaizduoklių"; 
$LANG['computers'][38]="Nėra prijungtų spausdintuvų"; 
$LANG['computers'][39]="Spausdintuvas(i)"; 
$LANG['computers'][40]="Vaizduoklis (iai)"; 
$LANG['computers'][46]="Įrenginiai"; 
$LANG['computers'][47]="Nėra prijungtų įrenginių"; 
$LANG['computers'][48]="Patalpos įrašas pakeistas. Susietų elementų įrašai taip pat."; 
$LANG['computers'][49]="Alternate username updated. The connected items have been updated using this alternate username."; 
$LANG['computers'][50]="Naudotojas ar grupė atnaujinti. Susiję įrašai išsaugo savo senąsias reikšmes."; 
$LANG['computers'][51]="Atnaujinimų autorius"; 
$LANG['computers'][52]="Version of the operating system"; 
$LANG['computers'][53]="Service Pack"; 
$LANG['computers'][54]="Nėra prijungto telefono"; 
$LANG['computers'][55]="Telefonas(i)"; 
$LANG['computers'][56]="Būsena atnaujinta. Prijungti elementai atnaujinti atsižvelgiant į šią būseną."; 

$LANG['connect'][0]="Tiesioginis(iai) prijungimas(i)"; 
$LANG['connect'][1]="Neprijungtas"; 
$LANG['connect'][15]="Automatinis šių elementų atnaujinimas"; 
$LANG['connect'][16]="Dėmesio! Šie elementai įrangos porai nesutampa"; 

$LANG['consumables'][0]="Ekspluatacinės m."; 
$LANG['consumables'][1]="Sandėlyje"; 
$LANG['consumables'][2]="Nuoroda"; 
$LANG['consumables'][7]="Medžiagų neįvesta"; 
$LANG['consumables'][9]="Sąrašas tuščias"; 
$LANG['consumables'][12]="Medžiagos tipas"; 
$LANG['consumables'][13]="Naujas"; 
$LANG['consumables'][15]="Used"; 
$LANG['consumables'][16]="Medžiaga(os)"; 
$LANG['consumables'][20]="Naujas"; 
$LANG['consumables'][22]="Used"; 
$LANG['consumables'][23]="State"; 
$LANG['consumables'][26]="Nuo kada naudojama"; 
$LANG['consumables'][32]="Teikti"; 
$LANG['consumables'][35]="Used consumables"; 
$LANG['consumables'][36]="Stock location"; 
$LANG['consumables'][37]="Grąžinti į sandėlį"; 
$LANG['consumables'][38]="Alert threshold"; 

$LANG['contract'][0]="Contract expired since the"; 
$LANG['contract'][1]="Contract with notice since the"; 

$LANG['crontask'][0]="Automatic actions"; 
$LANG['crontask'][1]="Synchronize equipments from OCSNG"; 
$LANG['crontask'][2]="Send alarms on cartridges"; 
$LANG['crontask'][3]="Send alarms on consumables"; 
$LANG['crontask'][4]="Send alarms on expired licenses"; 
$LANG['crontask'][5]="Send alarms on contracts"; 
$LANG['crontask'][6]="Send alarms on financial information"; 
$LANG['crontask'][7]="Clean old logs"; 
$LANG['crontask'][8]="Database optimization"; 
$LANG['crontask'][9]="Retrieve email (Mail receivers)"; 
$LANG['crontask'][10]="Check the MySQL replica"; 
$LANG['crontask'][11]="Check for new updates"; 
$LANG['crontask'][12]="Clean expired sessions"; 
$LANG['crontask'][13]="Clean generated graphics"; 
$LANG['crontask'][14]="Automatic tickets closing"; 
$LANG['crontask'][15]="Not solved tickets"; 
$LANG['crontask'][31]="Disabled"; 
$LANG['crontask'][32]="Scheduled"; 
$LANG['crontask'][33]="Running"; 
$LANG['crontask'][34]="GLPI"; 
$LANG['crontask'][35]="CLI"; 
$LANG['crontask'][36]="Run mode"; 
$LANG['crontask'][37]="Run frequency"; 
$LANG['crontask'][38]="Run period"; 
$LANG['crontask'][39]="Number of email to retrieve"; 
$LANG['crontask'][40]="Last run"; 
$LANG['crontask'][41]="Next run"; 
$LANG['crontask'][42]="As soon as possible"; 
$LANG['crontask'][43]="No action pending"; 
$LANG['crontask'][44]="Action completed, partially processed"; 
$LANG['crontask'][45]="Action completed, fully processed"; 
$LANG['crontask'][46]="Action completed, no processing required"; 
$LANG['crontask'][47]="Last run list"; 
$LANG['crontask'][48]="Start"; 
$LANG['crontask'][50]="Run count"; 
$LANG['crontask'][51]="Minimal time"; 
$LANG['crontask'][52]="Maximal time"; 
$LANG['crontask'][53]="Trukmė (vidurkis)"; 
$LANG['crontask'][55]="Minimal count"; 
$LANG['crontask'][56]="Maximal count"; 
$LANG['crontask'][57]="Kiekis (vidurkis)"; 
$LANG['crontask'][58]="Total count"; 
$LANG['crontask'][59]="Sparta (vidurkis)"; 
$LANG['crontask'][60]="System lock"; 
$LANG['crontask'][61]="Disabled plugin"; 
$LANG['crontask'][62]="Elements"; 

$LANG['devices'][0]="Įtraukti naują įrenginį"; 
$LANG['devices'][1]="Standusis diskas"; 
$LANG['devices'][2]="Vaizdo plokštė"; 
$LANG['devices'][3]="Tinklo plokstė"; 
$LANG['devices'][4]="Procesorius"; 
$LANG['devices'][5]="Sisteminė plokštė"; 
$LANG['devices'][6]="Memory"; 
$LANG['devices'][7]="Garso plokštė"; 
$LANG['devices'][19]="Diskai"; 
$LANG['devices'][20]="Valdikliai"; 
$LANG['devices'][21]="Kiti įrenginiai"; 
$LANG['devices'][22]="Korpusai"; 
$LANG['devices'][23]="Maitinimo blokas"; 
$LANG['devices'][24]="numatytieji"; 
$LANG['devices'][25]="Įrenginio įtraukimas"; 
$LANG['devices'][26]="Pašalinti įrenginį"; 

$LANG['device_case'][0]="Formatas"; 

$LANG['device_control'][0]="RAID"; 

$LANG['device_drive'][0]="Įrašymo galimybė"; 
$LANG['device_drive'][1]="Greitis"; 

$LANG['device_hdd'][0]="Rpm"; 
$LANG['device_hdd'][1]="Podėlis"; 
$LANG['device_hdd'][4]="Talpa"; 

$LANG['device_iface'][0]="Eiga"; 
$LANG['device_iface'][2]="Mac adresas"; 

$LANG['device_moboard'][0]="Lustų rinkinys"; 

$LANG['device_power'][0]="Maitinimas"; 
$LANG['device_power'][1]="ATX"; 

$LANG['device_ram'][1]="Dažnis"; 
$LANG['device_ram'][2]="Dydis"; 

$LANG['document'][1]="Checksum (SHA1)"; 
$LANG['document'][2]="Rinkmena"; 
$LANG['document'][3]="Antraštė"; 
$LANG['document'][4]="MIME tipas"; 
$LANG['document'][7]="Dokumento Tipas"; 
$LANG['document'][9]="Plėtinys"; 
$LANG['document'][10]="Piktograma"; 
$LANG['document'][11]="Autorizuotas parsisiuntimas"; 
$LANG['document'][15]="Atsisiuntimas"; 
$LANG['document'][16]="Pridėti dokumentą"; 
$LANG['document'][18]="Dokumentas"; 
$LANG['document'][19]="Susiję elementai"; 
$LANG['document'][21]="Susiję dokumentai"; 
$LANG['document'][22]="Ši rinkmena"; 
$LANG['document'][23]="File too large to be added."; 
$LANG['document'][24]="Sėkmingas rinkmenos pašalinimas"; 
$LANG['document'][25]="Nepavyko pašalinti rinkmenos"; 
$LANG['document'][26]="Rinkmena nepažeista. Išsiuntimas sėkmingas."; 
$LANG['document'][27]="Išsiuntimo sutrikimai, arba rinkmena per didelė. Laikinos rinkmenos perkėlimas nepavyko."; 
$LANG['document'][28]="No file specified."; 
$LANG['document'][29]="Nepavyko sukurti aplanko"; 
$LANG['document'][30]="Patikrinkite ar yra reikalingos prieeigos teisės"; 
$LANG['document'][31]="Nėra aplanko dokumentams"; 
$LANG['document'][32]="Neautorizuotas rinkmenos tipas"; 
$LANG['document'][33]="Internetinis adresas"; 
$LANG['document'][34]="Sukurti aplanką"; 
$LANG['document'][35]="Nėra aplanko išsiuntimui"; 
$LANG['document'][36]="Use a FTP installed file"; 
$LANG['document'][37]="Nėra prieinamos rinkmenos"; 
$LANG['document'][38]="Rinkmena nerasta"; 
$LANG['document'][39]="Dokumento perkėlimas atliktas"; 
$LANG['document'][40]="Nepavyko perkelti rinkmenos"; 
$LANG['document'][41]="Dokumento kopija atlikta"; 
$LANG['document'][42]="Pridėjo"; 
$LANG['document'][43]="Nežinoma rinkmena"; 
$LANG['document'][44]="Netinkamas vardas"; 
$LANG['document'][45]="Nėra reikalingų prieeigos teisių šiai rinkmenai"; 
$LANG['document'][46]="Nepavyko išsiųsti rinkmenos (per didelė apimtis)"; 
$LANG['document'][48]="A document with that filename has already been attached to (another) record"; 
$LANG['document'][49]="Rinkmena pakitusi (kontrolinė suma neatitinka)"; 
$LANG['document'][50]="Attached items"; 

$LANG['entity'][0]="Padalinys"; 
$LANG['entity'][2]="Pagrindinis padalinys"; 
$LANG['entity'][3]="Susieti su padaliniu"; 
$LANG['entity'][5]="Automatic computer assignment"; 
$LANG['entity'][6]="Automatinis naudotojo susiejimas"; 
$LANG['entity'][7]="medžio struktūra"; 
$LANG['entity'][8]="Pagal padalinius"; 
$LANG['entity'][9]="Pavaldūs padaliniai"; 
$LANG['entity'][10]="Select the desired entity"; 
$LANG['entity'][11]="to see the entity and its sub-entities"; 
$LANG['entity'][12]="LDAP attribute identifying entity"; 
$LANG['entity'][13]="TAG identifying entity"; 
$LANG['entity'][14]="Advanced informations"; 
$LANG['entity'][15]="LDAP directory of an entity"; 
$LANG['entity'][16]="Search filter (if needed)"; 
$LANG['entity'][17]="Automatic closing configuration"; 
$LANG['entity'][18]="Automatic closing of the tickets after"; 

$LANG['event'][0]="Source"; 
$LANG['event'][2]="Tarnyba"; 
$LANG['event'][3]="Lygmuo"; 
$LANG['event'][4]="Pranešimas"; 
$LANG['event'][18]="Laukas"; 
$LANG['event'][19]="Atnaujinti"; 
$LANG['event'][20]="Nėra istorijos"; 

$LANG['financial'][1]="Sutartis"; 
$LANG['financial'][2]="Pradėta"; 
$LANG['financial'][3]="finansinė informacija"; 
$LANG['financial'][4]="Numeris"; 
$LANG['financial'][5]="Kaina"; 
$LANG['financial'][6]="Sutarties tipas"; 
$LANG['financial'][8]="Terminas"; 
$LANG['financial'][9]="metai"; 
$LANG['financial'][10]="Pranešimas"; 
$LANG['financial'][11]="Sąskaitos kiekvieną"; 
$LANG['financial'][13]="Buhalterio telefonas"; 
$LANG['financial'][14]="Pirkimo data"; 
$LANG['financial'][15]="Warranty duration"; 
$LANG['financial'][16]="Duomenys apie garantiją"; 
$LANG['financial'][18]="Užsakymo numeris"; 
$LANG['financial'][19]="Pristatymo būdas"; 
$LANG['financial'][20]="Immobilizacijos numeris"; 
$LANG['financial'][21]="Kaina"; 
$LANG['financial'][22]="Amortizacijos tipas"; 
$LANG['financial'][23]="Amortizacinis laikotarpis"; 
$LANG['financial'][24]="Įtraukti kontaktinį asmenį"; 
$LANG['financial'][25]="Įtraukti tiekėją..."; 
$LANG['financial'][26]="Tiekėjas"; 
$LANG['financial'][30]="Fax"; 
$LANG['financial'][33]="Įtraukti kontaktinį asmenį"; 
$LANG['financial'][36]="Įtraukti sutartį"; 
$LANG['financial'][42]="Komercinė"; 
$LANG['financial'][43]="Techninis"; 
$LANG['financial'][44]="Adresas"; 
$LANG['financial'][45]="Tinklalapis"; 
$LANG['financial'][46]="Susiję kontaktiniai asmenys"; 
$LANG['financial'][47]="Tiesinis"; 
$LANG['financial'][48]="Degresinis"; 
$LANG['financial'][50]="Paruoštas"; 
$LANG['financial'][51]="Patalpa"; 
$LANG['financial'][52]="Lizingas"; 
$LANG['financial'][53]="Garantija"; 
$LANG['financial'][54]="Techninė priežiūra"; 
$LANG['financial'][55]="Programinis palaikymas"; 
$LANG['financial'][56]="Pilnas palaikymas"; 
$LANG['financial'][57]="mėnuo"; 
$LANG['financial'][59]="Darbo laikas"; 
$LANG['financial'][60]="per savaitę"; 
$LANG['financial'][61]="šeštadienis"; 
$LANG['financial'][62]="sekmadieniai ir šventės"; 
$LANG['financial'][65]="Susiję tiekėjai"; 
$LANG['financial'][66]="Susijusi(ios) sutartis(ys)"; 
$LANG['financial'][68]="Aktyvuoti finansinius duomenis"; 
$LANG['financial'][69]="Sutarties periodiškumas"; 
$LANG['financial'][76]="Kada pradėtas naudoti"; 
$LANG['financial'][77]="Amortizacijos koeficientas"; 
$LANG['financial'][78]="Kaina pasibaigus garantijai"; 
$LANG['financial'][79]="Pristato"; 
$LANG['financial'][80]="Garantijos pabaiga"; 
$LANG['financial'][81]="Account net value"; 
$LANG['financial'][82]="Sąskaitos numeris"; 
$LANG['financial'][83]="Max number of items"; 
$LANG['financial'][84]="Finansinė informacija bus ruošiniu pridedamiems elementams"; 
$LANG['financial'][85]="Reikalingas elementas nerastas"; 
$LANG['financial'][86]="End of contract"; 
$LANG['financial'][87]="Budžetas"; 
$LANG['financial'][88]="Baigiasi:"; 
$LANG['financial'][89]="TCO (value + tracking cost)"; 
$LANG['financial'][90]="Mėnesinis TCO"; 
$LANG['financial'][91]="TCO"; 
$LANG['financial'][92]="ANV"; 
$LANG['financial'][93]="Sutartys, kurioms galioti liko mažiau, nei 30 dienų"; 
$LANG['financial'][94]="Sutartys, kurioms liko galioti mažiau nei 7 dienos"; 
$LANG['financial'][95]="Sutartys, kurių galiojimas baigiasi šį mėnesį"; 
$LANG['financial'][96]="Šios savaitės pranešimai pagal sutartis"; 
$LANG['financial'][97]="Šios mėnesio pranešimai pagal sutartis"; 
$LANG['financial'][98]="Galiojimo pabaiga"; 
$LANG['financial'][99]="Termino pabaiga + Įspėjimas"; 
$LANG['financial'][100]="Pašto indeksas"; 
$LANG['financial'][101]="Miestas"; 
$LANG['financial'][102]="Šalis"; 
$LANG['financial'][103]="Šalis"; 
$LANG['financial'][104]="Susiję elementai"; 
$LANG['financial'][105]="automatiškai"; 
$LANG['financial'][106]="būtina"; 
$LANG['financial'][107]="Pratęsimas"; 
$LANG['financial'][108]="Total spent on the budget"; 
$LANG['financial'][109]="Total remaining on the budget"; 
$LANG['financial'][110]="Budgets"; 

$LANG['gmt'][0]="GMT"; 
$LANG['gmt'][1]="valanda(os)"; 
$LANG['gmt'][2]="h"; 

$LANG['help'][1]="Matrix of calculus for priority"; 
$LANG['help'][2]="Major"; 
$LANG['help'][3]="Labai aukštas"; 
$LANG['help'][4]="Aukštas"; 
$LANG['help'][5]="Vidutinis"; 
$LANG['help'][6]="Žemas"; 
$LANG['help'][7]="Labai žemas"; 
$LANG['help'][8]="Informuoti apie atliktus veiksmus"; 
$LANG['help'][11]="Mano e-pašto adresas"; 
$LANG['help'][14]="Išsiųsti pranešimą"; 
$LANG['help'][16]="If you want be notified about the action(s) taken, please enter your e-mail address."; 
$LANG['help'][18]="Jūsų pranešimas išsiųstas, užklausa išsaugota"; 
$LANG['help'][19]="Ačiū, kad naudojatės techninės pagalbos sistema"; 
$LANG['help'][22]="Kompiuterio ID paieška"; 
$LANG['help'][23]="Enter the first letters (user, item name, serial or asset number)"; 
$LANG['help'][24]="Įrangos tipas"; 
$LANG['help'][25]="Kompiuteris"; 
$LANG['help'][26]="Tinklo įranga"; 
$LANG['help'][27]="Spausdintuvas"; 
$LANG['help'][28]="Vaizduoklis"; 
$LANG['help'][29]="Įrenginys"; 
$LANG['help'][30]="Bendri"; 
$LANG['help'][31]="Programinė įranga"; 
$LANG['help'][35]="Telefonas"; 
$LANG['help'][40]="Būtina nurodyti antraštę paraiškai"; 
$LANG['help'][41]="Nenurodyta paraiškos kategorija"; 
$LANG['help'][42]="Very High"; 
$LANG['help'][43]="High"; 
$LANG['help'][44]="Medium"; 
$LANG['help'][45]="Low"; 
$LANG['help'][46]="Very Low"; 
$LANG['help'][47]="Very High"; 
$LANG['help'][48]="High"; 
$LANG['help'][49]="Medium"; 
$LANG['help'][50]="Low"; 
$LANG['help'][51]="Very Low"; 

$LANG['install'][0]="GLPI įdiegimas ir atnaujinimas"; 
$LANG['install'][1]="Pasirinkite 'Įdiegimas' naujam GLPI įdiegimui (duomenų bazė bus uždpildyta numatytosiomis reikšmėmis)"; 
$LANG['install'][2]="Pasirinkite 'Atnaujinti', jei yra įdiegta senesnės versijos GLPI sistema"; 
$LANG['install'][3]="Įdiegimas"; 
$LANG['install'][4]="Atnaujinti"; 
$LANG['install'][5]="Tikrinama sąlygos GLPI funkcionavimui"; 
$LANG['install'][6]="Testas atliktas"; 
$LANG['install'][7]="Rezultatai"; 
$LANG['install'][8]="Tikrinama PHP funkcionavimas"; 
$LANG['install'][9]="Įdiekite PHP ne žemesnės, kaip 5.xx versijos."; 
$LANG['install'][10]="GLPI is not compatible with the option zend.ze1_compatibility_mode = On."; 
$LANG['install'][11]="PHP versija ne žemiau 5.x - Puiku!"; 
$LANG['install'][12]="Tikrinama Sessions"; 
$LANG['install'][13]="PHP nepalaiko sesijų. Būtina kompiliuoti su sesijos palaikymu."; 
$LANG['install'][14]="Sesijos palaikymas veikia - Puiku!"; 
$LANG['install'][15]="Patikrinkite, ar įjungtas sesijos palaikymas PHP sąrankos rinkmenoje php.ini"; 
$LANG['install'][16]="Tikrinama rašymo leidimai rezervininėms rinkmenoms"; 
$LANG['install'][17]="Rinkmena nesukurta"; 
$LANG['install'][18]="Unofficial translations are also available"; 
$LANG['install'][19]="Rinkmena sukurta bet jos pašalinti neleidžiama"; 
$LANG['install'][20]="Rinkmena ir aplankas buvo sukurti ir pašalinti - Puiku!"; 
$LANG['install'][21]="Tikrinama rašymo leidimai dokumentų rinkmenoms"; 
$LANG['install'][22]="Rinkmena sukurta - Puiku !"; 
$LANG['install'][23]="Tikrinami rašymo leidimai nustatymų rinkmenoms"; 
$LANG['install'][24]="Initialization of the database"; 
$LANG['install'][25]="Tęsti?"; 
$LANG['install'][26]="Toliau"; 
$LANG['install'][27]="Bandyti dar kartą"; 
$LANG['install'][28]="Prisijungimo prie duomenų bazės sąranka"; 
$LANG['install'][29]="Duomenų bazės prisijungimo parametrai"; 
$LANG['install'][30]="Mysql tarnybinė stotis"; 
$LANG['install'][31]="Mysql naudotojas"; 
$LANG['install'][32]="Mysql slaptažodis"; 
$LANG['install'][34]="Tikrinamas prisijungimas prie duomenų bazės"; 
$LANG['install'][35]="Nepavyko prisijungimas prie duomenų bazės"; 
$LANG['install'][36]="Tarnybinės stoties pranešimas"; 
$LANG['install'][37]="Tarnybinės stoties ir/arba naudotojo vardo laukai neužpildyti"; 
$LANG['install'][38]="Nurodykite duomenų bazę:"; 
$LANG['install'][39]="Sukurti naują duomenų bazę arba naudoti esančią:"; 
$LANG['install'][40]="Nurodykite duomenų bazę atnaujinimui"; 
$LANG['install'][41]="Nėra galimybės naudotis duomenų baze:"; 
$LANG['install'][43]="OK - duomenų bazė inicijuota"; 
$LANG['install'][47]="Nėra galimybės įrašyti duomenų bazės sąrankos rinkmenoje"; 
$LANG['install'][48]="Klaida sukuriant duomenų bazę!"; 
$LANG['install'][49]="Nenurodėte duomenų bazės"; 
$LANG['install'][50]="Tikrinama rašymo leidimai sesijos rinkmenoms"; 
$LANG['install'][52]="Check write permissions for automatic actions files"; 
$LANG['install'][53]="Tikrinama rašymas į log rinkmenas"; 
$LANG['install'][55]="Įdiegimas baigtas"; 
$LANG['install'][57]="Numatytieji prisijungimo vardai / slaptažodžiai yra:"; 
$LANG['install'][58]="glpi/glpe administratoriaus prisijungimui"; 
$LANG['install'][59]="tech/tech techniko prisijungimui"; 
$LANG['install'][60]="normal/normal for the normal account"; 
$LANG['install'][61]="post-only/postonly for the postonly account"; 
$LANG['install'][62]="You can delete or modify these accounts as well as the initial data."; 
$LANG['install'][64]="Į GLPI"; 
$LANG['install'][65]="magic_quotes_sybase plėtinio testas"; 
$LANG['install'][66]="GLPI funkcionavimui būtina išjungti sąrankos parinktį magic_quotes_sybase;"; 
$LANG['install'][67]="Parinktis magic_quotes_sybase neįjungta - Puiku!"; 
$LANG['install'][68]="Test session auto start"; 
$LANG['install'][69]="session.auto_start is activated. See .htaccess file in the GLPI root for more information."; 
$LANG['install'][70]="Nėra galimybės sukurti rinkmenos prisijungimui prie duomenų bazės, patikrinkite leidimus rinkmenoms"; 
$LANG['install'][71]="Mysql plėtinių testas"; 
$LANG['install'][72]="Reikalingas php kompiliavimas su Mysql palaikymu"; 
$LANG['install'][73]="Ok - mysql_query() funkcija veikia - Puiku!"; 
$LANG['install'][74]="Testuojama Session_use_trans_sid"; 
$LANG['install'][75]="Reikia išjungti Session_use_trans_id parinktį PHP sąrankos rinkmenoje php.ini"; 
$LANG['install'][76]="Ok - sesijos palaikymas įjungtas, trans_id veikia - Puiku!"; 
$LANG['install'][77]="Etapas"; 
$LANG['install'][81]="Įdiegimo pradžia"; 
$LANG['install'][82]="Duomenų bazė sukurta"; 
$LANG['install'][85]="Funkcionavimas aptiktas - Puiku!"; 
$LANG['install'][86]="Atminties testas"; 
$LANG['install'][87]="Skirta atminties:"; 
$LANG['install'][88]="GLPI veikimui reikalinga bent 64MB"; 
$LANG['install'][89]="Puiku!"; 
$LANG['install'][90]="Padidinkite memory_limit parametro reikšmę sąrankos rinkmenoje php.ini"; 
$LANG['install'][91]="Skirta atminties > 64MB"; 
$LANG['install'][92]="Licencija"; 
$LANG['install'][93]="Perskaičiau licecijos sąlygas ir SUTINKU jų laikytis"; 
$LANG['install'][94]="Perskaičiau licencijos sąlygas ir NESUTINKU jų laikytis"; 
$LANG['install'][95]="Atmintis be apribojimų"; 
$LANG['install'][96]="Neapribota atmintis"; 
$LANG['install'][97]="Patikrinkite, ar PHP gali rašyti į aplanką:"; 
$LANG['install'][99]="Tikrinama rašymo prieeiga į podėlio rinkmenas"; 
$LANG['install'][100]="Aplankas nėsukurtas"; 
$LANG['install'][101]="Aplankas sukurtas bet po to nepašalintas"; 
$LANG['install'][102]="Test json functions"; 
$LANG['install'][103]="GLPI can't work correctly without the json_encode and json_decode functions"; 
$LANG['install'][104]="mbstring extension test"; 
$LANG['install'][105]="Mbstring extension of your parser PHP is not installed"; 
$LANG['install'][106]="Checking write permissions for graphic files"; 

$LANG['job'][2]="kas:"; 
$LANG['job'][4]="Užsakovas"; 
$LANG['job'][5]="Paskirta"; 
$LANG['job'][6]="Techninis darbuotojas"; 
$LANG['job'][7]="Task"; 
$LANG['job'][8]="last(s) ticket(s)"; 
$LANG['job'][9]="Follow-up"; 
$LANG['job'][11]="Aprašykite reikalą/įvykį"; 
$LANG['job'][12]="Nėra atsakymo į paraišką"; 
$LANG['job'][13]="New ticket"; 
$LANG['job'][15]="Solved"; 
$LANG['job'][19]="Atsakymai E-paštu"; 
$LANG['job'][20]="Suminis laikas"; 
$LANG['job'][21]="Valandos"; 
$LANG['job'][22]="Minutės"; 
$LANG['job'][29]="Pridėti naują atsakymą"; 
$LANG['job'][30]="Add a new task"; 
$LANG['job'][31]="Trukmė"; 
$LANG['job'][32]="Nėra"; 
$LANG['job'][33]="Tuščia aprašymo forma"; 
$LANG['job'][34]="Plan this task"; 
$LANG['job'][35]="Planavimas"; 
$LANG['job'][37]="Suvestinė informacija"; 
$LANG['job'][38]="Paraiška"; 
$LANG['job'][39]="Atnaujinti atsakymą"; 
$LANG['job'][40]="Laiko sąnaudos"; 
$LANG['job'][41]="Remonto darbų kaina"; 
$LANG['job'][42]="Medžiagų kaina"; 
$LANG['job'][43]="galutinė kaina"; 
$LANG['job'][44]="Gauta per"; 
$LANG['job'][45]="Source of follow-up"; 
$LANG['job'][46]="The ticket will be added in the entity"; 
$LANG['job'][47]="Costs"; 
$LANG['job'][48]="Type of solution"; 
$LANG['job'][49]="New task"; 
$LANG['job'][50]="No task for this ticket"; 
$LANG['job'][51]="Approval of the solution"; 
$LANG['job'][52]="Update task"; 
$LANG['job'][53]="Deletion of a task"; 
$LANG['job'][54]="Without a reply, the ticket will be automatically closed after"; 

$LANG['joblist'][0]="Būsena"; 
$LANG['joblist'][1]="Tik mano"; 
$LANG['joblist'][2]="Eiliškumas"; 
$LANG['joblist'][3]="Asmeninis + grupė(s)"; 
$LANG['joblist'][4]="Priskirtas"; 
$LANG['joblist'][6]="Aprašymas"; 
$LANG['joblist'][7]="Nauja paraiška duotam elementui..."; 
$LANG['joblist'][8]="Paraiškų nėra"; 
$LANG['joblist'][9]="Naujas"; 
$LANG['joblist'][10]="Uždarytas (išspręstas)"; 
$LANG['joblist'][11]="Atidaryta"; 
$LANG['joblist'][12]="Closed on"; 
$LANG['joblist'][13]="Tickets to be processed"; 
$LANG['joblist'][14]="Solved on"; 
$LANG['joblist'][16]="Nėra vykdomų paraiškų."; 
$LANG['joblist'][17]="Uždarytas (neišspręsta)"; 
$LANG['joblist'][18]="Vykdomas (priskirta)"; 
$LANG['joblist'][19]="Vykdomas (suplanuota)"; 
$LANG['joblist'][21]="Vykdomas"; 
$LANG['joblist'][26]="Eilėje"; 
$LANG['joblist'][27]="E-pašto adresas"; 
$LANG['joblist'][28]="Tickets on linked items"; 
$LANG['joblist'][29]="Urgency"; 
$LANG['joblist'][30]="Impact"; 
$LANG['joblist'][32]="Solved"; 
$LANG['joblist'][33]="Closed"; 
$LANG['joblist'][34]="Not solved"; 
$LANG['joblist'][35]="Not closed"; 
$LANG['joblist'][36]="Status value in database"; 

$LANG['jobresolution'][1]="Solution"; 
$LANG['jobresolution'][3]="Approved solution"; 
$LANG['jobresolution'][4]="Refused solution"; 
$LANG['jobresolution'][5]="If you reject the solution, you must specify a reason"; 

$LANG['knowbase'][1]="DUK"; 
$LANG['knowbase'][5]="Put this item in the FAQ"; 
$LANG['knowbase'][6]="Parinkite kategoriją elementui"; 
$LANG['knowbase'][7]="Delete this item from the FAQ"; 
$LANG['knowbase'][8]="Keisti šį elementą"; 
$LANG['knowbase'][9]="Pašalinti šį elementą"; 
$LANG['knowbase'][10]="This item is part of the FAQ"; 
$LANG['knowbase'][11]="This item is not part of the FAQ"; 
$LANG['knowbase'][12]="Pagrindinis"; 
$LANG['knowbase'][13]="Kategorija"; 
$LANG['knowbase'][14]="Tema"; 
$LANG['knowbase'][15]="Turinys"; 
$LANG['knowbase'][24]="Prieeiga prie Dažniausiai Užduodamų Klausimų"; 
$LANG['knowbase'][26]="Rodiniai"; 
$LANG['knowbase'][27]="Įjungtas"; 
$LANG['knowbase'][29]="Vėliausi įrašai"; 
$LANG['knowbase'][30]="Dažniausi klausimai"; 

$LANG['ldap'][0]="Bulk import users from a LDAP directory"; 
$LANG['ldap'][1]="Importuotų duomenų sinchronizavimas"; 
$LANG['ldap'][2]="Importuoti naujus"; 
$LANG['ldap'][3]="Nerasta naudotojų importui"; 
$LANG['ldap'][4]="Išrinkti iš LDAP"; 
$LANG['ldap'][5]="Nurodykite LDAP aplanką naudotojų įkėlimui"; 
$LANG['ldap'][6]="Nepavyksta prisijungti prie LDAP"; 
$LANG['ldap'][7]="Nenurodyta LDAP stotis"; 
$LANG['ldap'][8]="Warning: The request exceeds the limit of the directory. The results are only partial."; 
$LANG['ldap'][9]="Prisijungimo prie LDAP testavimas"; 
$LANG['ldap'][12]="Duomenų sinchronizacija"; 
$LANG['ldap'][13]="in the LDAP directory"; 
$LANG['ldap'][14]="GLPI"; 
$LANG['ldap'][15]="Sinchronizuoti"; 
$LANG['ldap'][16]="Išankstiniai nustatymai"; 
$LANG['ldap'][17]="Active Directory"; 
$LANG['ldap'][18]="List of LDAP directory replicates"; 
$LANG['ldap'][19]="Kopijuoti"; 
$LANG['ldap'][20]="Add a LDAP directory replica"; 
$LANG['ldap'][21]="Pagrindinė stotis"; 
$LANG['ldap'][22]="Kopijuoti"; 
$LANG['ldap'][23]="Bulk import groups from a LDAP directory"; 
$LANG['ldap'][24]="Naujų grupių importas"; 
$LANG['ldap'][25]="Nėra importuojamų grupių"; 
$LANG['ldap'][30]="Ką daryti su LDAP sinonimais"; 
$LANG['ldap'][31]="Never dereferenced (numatytoji)"; 
$LANG['ldap'][32]="Visada peradresuojant"; 
$LANG['ldap'][33]="Atsietas paieškos metu (ne tada, kai patalpintas)"; 
$LANG['ldap'][34]="Atsietas patalpinant (bet ne paieškos metu)"; 
$LANG['ldap'][35]="Import an user"; 
$LANG['ldap'][36]="No directory associated to entity : search impossible"; 
$LANG['ldap'][38]="Search criterias for users"; 
$LANG['ldap'][39]="Advanced"; 
$LANG['ldap'][40]="Simple"; 
$LANG['ldap'][41]="To change"; 
$LANG['ldap'][42]="No directory selected"; 
$LANG['ldap'][43]="No users to be synchronized"; 
$LANG['ldap'][44]="Default server"; 
$LANG['ldap'][45]="Action when a user is deleted from the LDAP directory"; 
$LANG['ldap'][46]="Withdraw accreditations and groups (dynamics)"; 
$LANG['ldap'][47]="Put in trash"; 
$LANG['ldap'][48]="Deleted user in LDAP directory"; 
$LANG['ldap'][49]="View users added since"; 
$LANG['ldap'][50]="View users updated since"; 
$LANG['ldap'][52]="Less than"; 
$LANG['ldap'][53]="More than"; 
$LANG['ldap'][54]="Enable filtering by date"; 
$LANG['ldap'][55]="Disable filtering by date"; 
$LANG['ldap'][56]="Weeks"; 

$LANG['links'][1]="Nuoroda arba rinkmenos vardas"; 
$LANG['links'][4]="Susietas įrangos tipas"; 
$LANG['links'][6]="Valid tags"; 
$LANG['links'][7]="Nuoroda netiksli"; 
$LANG['links'][9]="Rinkmenos turinys"; 

$LANG['log'][1]="sistema"; 
$LANG['log'][16]="planavimas"; 
$LANG['log'][18]="įrenginiai"; 
$LANG['log'][20]="elementas pridėtas"; 
$LANG['log'][21]="atnaujinti elementą"; 
$LANG['log'][22]="pašalinti elementą"; 
$LANG['log'][23]="grąžinti elementą"; 
$LANG['log'][24]="išmesti elementą"; 
$LANG['log'][26]="atjungti elementą"; 
$LANG['log'][27]="elemento prijungimas"; 
$LANG['log'][28]="atnaujinti įrenginio savybes"; 
$LANG['log'][29]="approval/refusal of the solution"; 
$LANG['log'][30]="susieti tipą"; 
$LANG['log'][31]="pašalinti tipą"; 
$LANG['log'][32]="add a link with an item"; 
$LANG['log'][33]="pašalinti nuorodą su elementu"; 
$LANG['log'][34]="pridėti nuorodą su įmonės vardu"; 
$LANG['log'][35]="pašalinti nuorodą su įmone"; 
$LANG['log'][40]="IP sujungimas"; 
$LANG['log'][41]="Nepavyko prijungti"; 
$LANG['log'][42]="Rezervavimas"; 
$LANG['log'][44]="Antraštė"; 
$LANG['log'][45]="Sėkmingai"; 
$LANG['log'][46]="Nepavyko"; 
$LANG['log'][48]="naudotojo įtraukimas į grupę"; 
$LANG['log'][49]="pašalinti naudotoją iš grupės"; 
$LANG['log'][55]="Sujungimas"; 
$LANG['log'][59]="Automatic action"; 
$LANG['log'][60]="use unitary management for this item"; 
$LANG['log'][61]="pridėti naudotoją padaliniui"; 
$LANG['log'][62]="visiškai pašalinti šį naudotoją"; 
$LANG['log'][64]="modification of field"; 
$LANG['log'][65]="sąlyga"; 
$LANG['log'][66]="Saugumas"; 
$LANG['log'][67]="pakeitimas pastabose"; 
$LANG['log'][70]="tinklo prievadas įtrauktas"; 
$LANG['log'][71]="pridėti keli tinklo prievadai"; 
$LANG['log'][73]="tinklo prievadas pašalintas"; 
$LANG['log'][74]="pašalinti keli tinklo prievadai"; 
$LANG['log'][75]="tinklo prievadas perkeltas"; 
$LANG['log'][77]="associate a VLAN to a network port"; 
$LANG['log'][78]="associate a VLAN to several ports"; 
$LANG['log'][79]="vlan dissociated from a network port"; 
$LANG['log'][80]="dissociation of a VLAN from multiple network ports"; 
$LANG['log'][82]="pridėta versija"; 
$LANG['log'][83]="modification of version"; 
$LANG['log'][84]="version's deletion"; 
$LANG['log'][85]="pridėta licenzija"; 
$LANG['log'][86]="modification of licence"; 
$LANG['log'][87]="licence's deletion"; 
$LANG['log'][88]="pridedamos kasetės"; 
$LANG['log'][89]="pridedamos ekspluatacinės medžiagos"; 
$LANG['log'][90]="deletion of a cartridge"; 
$LANG['log'][91]="deletion of a consumable"; 
$LANG['log'][92]="restoration of a cartridge"; 
$LANG['log'][93]="restoration of a consumable"; 
$LANG['log'][94]="kasečių atnaujinimas"; 
$LANG['log'][95]="kasečių įdiegimas"; 
$LANG['log'][96]="kasečių išėmimas"; 
$LANG['log'][97]="ekspl. medžiagų stoka naudotojui"; 
$LANG['log'][98]="add an element"; 
$LANG['log'][99]="modification of an item"; 
$LANG['log'][100]="deletion of an item"; 

$LANG['login'][0]="Paskutinį kartą jungtasi"; 
$LANG['login'][1]="Prisijungti dar kartą"; 
$LANG['login'][2]="LDAP directory"; 
$LANG['login'][3]="IMAP/POP"; 
$LANG['login'][4]="CAS"; 
$LANG['login'][5]="Prieeiga draudžiama"; 
$LANG['login'][6]="Prisijungti"; 
$LANG['login'][7]="Slaptažodis"; 
$LANG['login'][8]="Neįvestas naudotojo vardas arba slaptažodis"; 
$LANG['login'][9]="Neprisijungęs"; 
$LANG['login'][10]="Tapatybės nustatymas"; 
$LANG['login'][11]="User not authorized to connect in GLPI"; 
$LANG['login'][12]="Klaidingas naudotojo vardas arba slaptažodis"; 
$LANG['login'][13]="Neįvestas slaptažodis"; 
$LANG['login'][14]="unknown user"; 
$LANG['login'][15]="User not found or several users found"; 
$LANG['login'][16]="unsuccessful authorization in LDAP"; 
$LANG['login'][18]="įdiegtasis GLPI"; 
$LANG['login'][20]="Neturite prieigos šiai programai, nes jūsų paskyra buvo pašalinta ar išjungta"; 
$LANG['login'][21]="Test connection to IMAP/POP server"; 
$LANG['login'][22]="Test successful"; 
$LANG['login'][23]="Test failed"; 
$LANG['login'][24]="Paskutinį kartą prisijungta"; 
$LANG['login'][25]="You don't have right to connect"; 
$LANG['login'][26]="You must activate the JavaScript function of your navigator"; 
$LANG['login'][27]="You must accept cookies to reach this application"; 
$LANG['login'][30]="Tapatybės nustatymo būdo pakeitimas"; 
$LANG['login'][31]="Authentication on a LDAP directory"; 
$LANG['login'][32]="Tapatybės nustatymas iš GLPI duomenų bazės"; 
$LANG['login'][33]="Tapatybės nustatymas iš IMAP/POP tarnybinės stoties"; 

$LANG['mailgate'][0]="Siunčiamo pašto priėmimo stotis"; 
$LANG['mailgate'][2]="Atsisiųsti paraiškas e-paštu"; 
$LANG['mailgate'][3]="Gautų ir prieinamų laiškų skaičius"; 
$LANG['mailgate'][4]="Nėra mbstring plėtinio. Perspėjimas dėl naudojamų simbolių rinkinių."; 
$LANG['mailgate'][5]="Prisegta rinkmena sugadinta"; 
$LANG['mailgate'][6]="Too large attached file"; 
$LANG['mailgate'][7]="Maximum size of each file imported by the mail receiver"; 
$LANG['mailgate'][9]="Your email could not be processed.\nIf the problem persists, contact the administrator"; 
$LANG['mailgate'][10]="Email refused"; 
$LANG['mailgate'][11]="Process of emails import"; 
$LANG['mailgate'][12]="Unable to affect the email to an entity"; 
$LANG['mailgate'][13]="Reason of rebuff"; 
$LANG['mailgate'][14]="Email not found. Impossible import"; 
$LANG['mailgate'][16]="Re:"; 

$LANG['mailing'][0]="----------------------------------------------------------"; 
$LANG['mailing'][1]="======================================================================"; 
$LANG['mailing'][4]="Already done followup(s)"; 
$LANG['mailing'][5]="Paraiškos aprašymas"; 
$LANG['mailing'][10]="Naujas paraiškos peradresavimas"; 
$LANG['mailing'][12]="Paraiškos priskyrimas"; 
$LANG['mailing'][14]="Update of the category of the ticket"; 
$LANG['mailing'][15]="Update of the priority of the ticket"; 
$LANG['mailing'][17]="Update of the item of the ticket"; 
$LANG['mailing'][18]="Update the author of the ticket"; 
$LANG['mailing'][19]="Naujas rezervavimas"; 
$LANG['mailing'][20]="Update the group of the ticket"; 
$LANG['mailing'][21]="Pakeitimas paraiškos teikėjuose"; 
$LANG['mailing'][23]="Rezervavimo keitimas"; 
$LANG['mailing'][26]="Pridėtas dokumentas:"; 
$LANG['mailing'][27]="Update of the status of the ticket"; 
$LANG['mailing'][29]="Rezervacijos atšaukimas"; 
$LANG['mailing'][30]="Ticket Update"; 
$LANG['mailing'][31]="This is a test email to check that the email system works"; 
$LANG['mailing'][32]="Pašto patikrinimas"; 
$LANG['mailing'][33]="Perspėjimas dėl kasečių"; 
$LANG['mailing'][35]="Threshold of alarm reached for the type of consumable:"; 
$LANG['mailing'][36]="Įspėjimas dėl medžiagų"; 
$LANG['mailing'][37]="Įspėjimo apie sutartį laikas:"; 
$LANG['mailing'][39]="Įspėjimas dėl sutarčių"; 
$LANG['mailing'][40]="Pasibaigė garantinis laikotarpis:"; 
$LANG['mailing'][41]="Finansinės info Aliarmas"; 
$LANG['mailing'][42]="Pakeitimas einamosioms išlaidoms"; 
$LANG['mailing'][43]="Pakeitimas fiksuotoms išlaidoms"; 
$LANG['mailing'][44]="Pakeitimas medžiagų išlaidoms"; 
$LANG['mailing'][45]="Pakeisti paraiškos antraštę"; 
$LANG['mailing'][46]="Pakeisti paraiškos aprašymą"; 
$LANG['mailing'][47]="Klaida išsiunčiant laišką"; 
$LANG['mailing'][48]="Pakeitimas pradžios datoje"; 
$LANG['mailing'][49]="Pakeitimas pabaigos datoje"; 
$LANG['mailing'][50]="Pakeisti paraiškos gavėją"; 
$LANG['mailing'][51]="Nebegaliojanti licencija:"; 
$LANG['mailing'][53]="Change of solution"; 
$LANG['mailing'][54]="Expiry date"; 
$LANG['mailing'][100]="Nėra aprašytos kategorijos"; 
$LANG['mailing'][101]="Laiškų nukreipimas įjungtas"; 
$LANG['mailing'][102]="Laiškų nukreipimas išjungtas"; 
$LANG['mailing'][104]="Persiuntimo trukmė"; 
$LANG['mailing'][105]="Nepriskirtas"; 
$LANG['mailing'][107]="Nieko"; 
$LANG['mailing'][109]="Nėra grupės"; 
$LANG['mailing'][110]="Klaidingas pašto adresas"; 
$LANG['mailing'][113]="Notification templates"; 
$LANG['mailing'][114]="Body"; 
$LANG['mailing'][115]="Main part of email"; 
$LANG['mailing'][116]="HTML"; 
$LANG['mailing'][117]="text"; 
$LANG['mailing'][118]="Email"; 
$LANG['mailing'][119]="Occurrence"; 
$LANG['mailing'][120]="Notification method"; 
$LANG['mailing'][121]="Recipients"; 
$LANG['mailing'][122]="Task(s) already done"; 
$LANG['mailing'][123]="Solved ticket"; 
$LANG['mailing'][124]="Add a new translation"; 
$LANG['mailing'][125]="Default translation"; 
$LANG['mailing'][126]="Template translation"; 
$LANG['mailing'][127]="Closing of the ticket"; 
$LANG['mailing'][128]="leave the field empty for a generation from HTML"; 
$LANG['mailing'][129]="Deletion of a ticket"; 
$LANG['mailing'][130]="From"; 
$LANG['mailing'][131]="Recipient"; 
$LANG['mailing'][132]="Email header"; 
$LANG['mailing'][133]="Delete email(s)"; 
$LANG['mailing'][134]="Updating follow-up"; 
$LANG['mailing'][135]="Follow-up's deletion"; 
$LANG['mailing'][136]="Reservation expired"; 
$LANG['mailing'][137]="Hardware user"; 
$LANG['mailing'][138]="List of available tags"; 
$LANG['mailing'][139]="Label"; 
$LANG['mailing'][140]="Tag"; 
$LANG['mailing'][141]="Followups"; 
$LANG['mailing'][142]="Tasks"; 
$LANG['mailing'][143]="Validations"; 
$LANG['mailing'][144]="Historical"; 
$LANG['mailing'][145]="List of values"; 
$LANG['mailing'][146]="Single value"; 
$LANG['mailing'][147]="Possible value(s)"; 

$LANG['Menu'][0]="Kompiuteriai"; 
$LANG['Menu'][1]="Tinklo įranga"; 
$LANG['Menu'][2]="Spausdintuvai"; 
$LANG['Menu'][3]="Vaizduokliai"; 
$LANG['Menu'][4]="Programinė įranga"; 
$LANG['Menu'][5]="Tickets"; 
$LANG['Menu'][6]="Suvestinės"; 
$LANG['Menu'][11]="Nustatymai"; 
$LANG['Menu'][12]="Maintenance"; 
$LANG['Menu'][13]="Statistika"; 
$LANG['Menu'][14]="Naudotojai"; 
$LANG['Menu'][15]="Administravimas"; 
$LANG['Menu'][16]="Įrenginiai"; 
$LANG['Menu'][17]="Rezervavimas"; 
$LANG['Menu'][18]="Įrankiai"; 
$LANG['Menu'][19]="Knowledge base"; 
$LANG['Menu'][20]="DUK"; 
$LANG['Menu'][21]="Kasetės"; 
$LANG['Menu'][22]="Kontaktai"; 
$LANG['Menu'][23]="Tiekėjai"; 
$LANG['Menu'][24]="Finansinė Informacija"; 
$LANG['Menu'][25]="Sutartys"; 
$LANG['Menu'][26]="Valdymas"; 
$LANG['Menu'][27]="Dokumentai"; 
$LANG['Menu'][28]="Būsena"; 
$LANG['Menu'][29]="Planavimas"; 
$LANG['Menu'][30]="Žurnalai"; 
$LANG['Menu'][31]="Simplified interface"; 
$LANG['Menu'][32]="Ekspl. medžiagos"; 
$LANG['Menu'][33]="OSCNG"; 
$LANG['Menu'][34]="Telefonai"; 
$LANG['Menu'][35]="Profilis"; 
$LANG['Menu'][36]="Grupės"; 
$LANG['Menu'][37]="Padaliniai"; 
$LANG['Menu'][38]="Inventorius"; 
$LANG['Menu'][39]="Siunčiamo pašto stotys"; 
$LANG['Menu'][40]="Žymelės"; 
$LANG['Menu'][41]="Rights"; 

$LANG['monitors'][14]="Mikrofonas"; 
$LANG['monitors'][15]="Garsiakalbiai"; 
$LANG['monitors'][18]="Gairelės"; 
$LANG['monitors'][19]="Sub-D"; 
$LANG['monitors'][20]="BNC"; 
$LANG['monitors'][21]="Dydis"; 
$LANG['monitors'][32]="DVI"; 
$LANG['monitors'][33]="Suvestinė"; 

$LANG['networking'][4]="Network port"; 
$LANG['networking'][5]="Memory (MB)"; 
$LANG['networking'][6]="Tinklo prievadas"; 
$LANG['networking'][13]="Surasti tinklo prievadai"; 
$LANG['networking'][14]="IP"; 
$LANG['networking'][15]="MAC"; 
$LANG['networking'][17]="Prisijungta prie"; 
$LANG['networking'][19]="Pridėti tinklo prievadą..."; 
$LANG['networking'][21]="Port number"; 
$LANG['networking'][25]="on"; 
$LANG['networking'][37]="networking port(s) found"; 
$LANG['networking'][44]="The port"; 
$LANG['networking'][46]="Pridėti kitus prievadus..."; 
$LANG['networking'][47]="Nuo"; 
$LANG['networking'][48]="Iki"; 
$LANG['networking'][51]="Tinklo taškas"; 
$LANG['networking'][55]="Susieti VLAN"; 
$LANG['networking'][56]="VLAN"; 
$LANG['networking'][57]="Išrinkti MAC adresą iš sąrašo arba nurodyti jį žemiau"; 
$LANG['networking'][58]="Dissociate a VLAN"; 
$LANG['networking'][59]="Tinklo sietuvas (gateway)"; 
$LANG['networking'][60]="Kaukė"; 
$LANG['networking'][61]="Subnet"; 

$LANG['ocsconfig'][1]="OCSNG database user"; 
$LANG['ocsconfig'][2]="Host for the OCSNG database"; 
$LANG['ocsconfig'][3]="OCSNG user password"; 
$LANG['ocsconfig'][4]="Name of the OCSNG database"; 
$LANG['ocsconfig'][5]="Įkelties sąlygos"; 
$LANG['ocsconfig'][6]="Ignore in OCSNG import"; 
$LANG['ocsconfig'][7]="OCSNG database in UTF8"; 
$LANG['ocsconfig'][9]="Exclude the following tags (separator $, nothing for all)"; 
$LANG['ocsconfig'][10]="Visuminis įkėlimas"; 
$LANG['ocsconfig'][11]="Nėra įkelties"; 
$LANG['ocsconfig'][12]="Unit import"; 
$LANG['ocsconfig'][13]="Unit import: everything is imported 'as-is'"; 
$LANG['ocsconfig'][14]="Bendra įkeltis: viskas įkelta, bet medžiagos tvarkomos bendrai (be dvigubo žiedo)"; 
$LANG['ocsconfig'][15]="Nėra įkelties: papildinys neįkels šių elementų"; 
$LANG['ocsconfig'][16]="Numatytoji būsena"; 
$LANG['ocsconfig'][17]="Apriboti įkėlimą iki šių žymų (skirtuko $, nothing for all)"; 
$LANG['ocsconfig'][18]="Pirma, patikrinkite, ar besidubliuojantys tvarkomi iš OCSNG"; 
$LANG['ocsconfig'][19]="Unit import on serial number"; 
$LANG['ocsconfig'][27]="Bendrai"; 
$LANG['ocsconfig'][36]="Vartikliai (modemai)"; 
$LANG['ocsconfig'][37]="Prievadai"; 
$LANG['ocsconfig'][38]="Use the OCSNG software dictionary"; 
$LANG['ocsconfig'][39]="OCSNG TAG"; 
$LANG['ocsconfig'][40]="Number of items to synchronize via the automatic OCSNG action"; 
$LANG['ocsconfig'][41]="Registras"; 
$LANG['ocsconfig'][43]="OCSNG Administrative Information"; 
$LANG['ocsconfig'][48]="veiksmai atsijungiant"; 
$LANG['ocsconfig'][49]="Trash"; 
$LANG['ocsconfig'][50]="Pašalinimas"; 
$LANG['ocsconfig'][52]="Automatic connection of computers"; 
$LANG['ocsconfig'][53]="Enable the automatic link"; 
$LANG['ocsconfig'][54]="Existence criteria of a computer"; 
$LANG['ocsconfig'][55]="Find computers having the status"; 
$LANG['ocsconfig'][56]="tuščias"; 
$LANG['ocsconfig'][57]="lygus"; 
$LANG['ocsconfig'][58]="The link automatically connects a GLPI computer with one in OCSNG.<br>This option is taken into account during manual link and by synchronization scripts."; 
$LANG['ocsconfig'][59]="Web address of the OCSNG console"; 

$LANG['ocsng'][0]="OCS Inventory NG"; 
$LANG['ocsng'][1]="Synchronize computers already imported"; 
$LANG['ocsng'][2]="Įkelti naujus kompiuterius"; 
$LANG['ocsng'][3]="Clean links between GLPI and OCSNG"; 
$LANG['ocsng'][4]="Susieti naujus OCS kompiuterius su esamais GLPI kompiuteriais"; 
$LANG['ocsng'][5]="Įkelti naujus kompiuterius"; 
$LANG['ocsng'][6]="Automatinis atnaujinimas"; 
$LANG['ocsng'][7]="Įkelta iš OCSNG"; 
$LANG['ocsng'][8]="Sėkmingai įkelta"; 
$LANG['ocsng'][9]="No new computer to be imported"; 
$LANG['ocsng'][10]="Computers updated in OCSNG"; 
$LANG['ocsng'][11]="Update computers"; 
$LANG['ocsng'][12]="No new computer to be updated"; 
$LANG['ocsng'][13]="Įkelti duomenis į GLPI"; 
$LANG['ocsng'][14]="Last OCSNG inventory date"; 
$LANG['ocsng'][15]="Nėra užsklęstų laukų"; 
$LANG['ocsng'][16]="Užsklęstos žymos"; 
$LANG['ocsng'][18]="Connection to OCSNG database successful"; 
$LANG['ocsng'][19]="Valid OCSNG configuration and version"; 
$LANG['ocsng'][20]="Invalid OCSNG Version: RC3 is required"; 
$LANG['ocsng'][21]="Connection to the OCSNG database failed"; 
$LANG['ocsng'][22]="Dėmesio! Importuojami duomenys pakeis dabartinius įrašus (žiūrėti nustatymuose)"; 
$LANG['ocsng'][23]="Unable to import, GLPI computer is already related to an element of OCSNG"; 
$LANG['ocsng'][24]="Sinchronizuoti besąlygiškai"; 
$LANG['ocsng'][26]="Choice of an OCSNG server"; 
$LANG['ocsng'][27]="No OCSNG server defined"; 
$LANG['ocsng'][29]="OCSNG server"; 
$LANG['ocsng'][30]="Užsklęstas vaizduoklis"; 
$LANG['ocsng'][32]="Užsklęstas įrenginys(iai)"; 
$LANG['ocsng'][34]="Užsklęstas spausdintuvas(ai)"; 
$LANG['ocsng'][36]="Paskirties padalinys"; 
$LANG['ocsng'][37]="Aktyvinti peržiūrą"; 
$LANG['ocsng'][38]="Be peržiūros"; 
$LANG['ocsng'][40]="Atitinka taisyklę ?"; 
$LANG['ocsng'][41]="Rankinė įkeltis"; 
$LANG['ocsng'][42]="Invalid OCSNG configuration (TRACE_DELETED must be active)"; 
$LANG['ocsng'][43]="Access denied on OCSNG database (Need write rights on hardware.CHECKSUM necessary)"; 
$LANG['ocsng'][44]="Access denied on OCSNG database (Delete rights in deleted_equiv table necessary)"; 
$LANG['ocsng'][45]="OCS ID"; 
$LANG['ocsng'][46]="Deleted in OCSNG"; 
$LANG['ocsng'][47]="Linked with an OCSNG computer"; 
$LANG['ocsng'][48]="The OCSNG ID of the computer changed"; 
$LANG['ocsng'][49]="Agentas"; 
$LANG['ocsng'][50]="Užsklęsti IP"; 
$LANG['ocsng'][52]="Užsklęsta programinė įranga"; 
$LANG['ocsng'][54]="Software deleted by OCSNG synchronization"; 
$LANG['ocsng'][55]="Volume(s) locked(s)"; 
$LANG['ocsng'][57]="OCSNG Interface"; 

$LANG['pager'][1]="iki"; 
$LANG['pager'][2]="nuo"; 
$LANG['pager'][3]="iš"; 
$LANG['pager'][4]="Rodymas"; 
$LANG['pager'][5]="elementai"; 

$LANG['peripherals'][18]="Prekinis ženklas"; 
$LANG['peripherals'][31]="Bendras valdymas"; 
$LANG['peripherals'][32]="Įtaiso tvarkymas"; 
$LANG['peripherals'][33]="Valdymo tipas"; 

$LANG['phones'][18]="Prekinis ženklas"; 
$LANG['phones'][36]="Maitinimas"; 
$LANG['phones'][38]="Ausinės"; 
$LANG['phones'][39]="Garsiakalbis"; 
$LANG['phones'][40]="Eilučių skaičius"; 

$LANG['planning'][0]="Nurodytu laiku šiam technikui yra suplanuota kita užduotis"; 
$LANG['planning'][1]="Klaida nurodant datą. Pradžios data yra vėlesnė nei pabaigos data."; 
$LANG['planning'][5]="Diena"; 
$LANG['planning'][6]="Savaitė"; 
$LANG['planning'][8]="Sekimas"; 
$LANG['planning'][9]="Pagal"; 
$LANG['planning'][10]="Ical"; 
$LANG['planning'][11]="Webcal"; 
$LANG['planning'][12]="Download the planning in Ical format"; 
$LANG['planning'][13]="webcal://Synchronization"; 
$LANG['planning'][14]="Mėnuo"; 
$LANG['planning'][15]="Mano planavimas"; 
$LANG['planning'][16]="Informacija"; 
$LANG['planning'][17]="Atlikti"; 
$LANG['planning'][18]="Atlikta"; 

$LANG['plugins'][0]="Papildinių sąrašas"; 
$LANG['plugins'][2]="Installed / not configured"; 
$LANG['plugins'][3]="Installed / not activated"; 
$LANG['plugins'][4]="Error / to clean"; 
$LANG['plugins'][5]="Non-existent function(s)"; 
$LANG['plugins'][6]="To update"; 
$LANG['plugins'][7]="No plugin installed"; 
$LANG['plugins'][8]="See the catalog of plugins"; 
$LANG['plugins'][9]="Authors"; 
$LANG['plugins'][10]="Incompatible plugin with this version of GLPI"; 

$LANG['printers'][14]="Nuoseklusis"; 
$LANG['printers'][15]="Lygiagretusis"; 
$LANG['printers'][18]="Prievadai"; 
$LANG['printers'][27]="USB"; 
$LANG['printers'][28]="Ethernet"; 
$LANG['printers'][29]="Wifi"; 
$LANG['printers'][30]="Pradiniai skaitliuko parodymai"; 
$LANG['printers'][31]="Atspausta puslapių"; 

$LANG['profiles'][0]="Bendra teisė"; 
$LANG['profiles'][1]="Padalinio teisės"; 
$LANG['profiles'][2]="Profile's interface"; 
$LANG['profiles'][4]="Add a followup to tickets of associated group(s)"; 
$LANG['profiles'][5]="Sukurti paskyrą"; 
$LANG['profiles'][6]="Add a followup to tickets (requester)"; 
$LANG['profiles'][7]="Visos paraiškos"; 
$LANG['profiles'][8]="View all follow-ups and tasks (public and private)"; 
$LANG['profiles'][9]="Show public followups and tasks"; 
$LANG['profiles'][10]="Skaityti"; 
$LANG['profiles'][11]="Rašyti"; 
$LANG['profiles'][12]="Nėra prieigos"; 
$LANG['profiles'][13]="Numatytasis profilis"; 
$LANG['profiles'][14]="Pašalinti paraišką"; 
$LANG['profiles'][15]="Pridėti nukreipimus visoms paraiškoms"; 
$LANG['profiles'][16]="Užimtas paraiškoje"; 
$LANG['profiles'][17]="Perimti paraišką"; 
$LANG['profiles'][18]="Atnaujinti paraišką"; 
$LANG['profiles'][19]="Priskirti paraišką"; 
$LANG['profiles'][20]="Asmeniškai suplanuoti veiksmai"; 
$LANG['profiles'][21]="View all plannings"; 
$LANG['profiles'][22]="Profilis"; 
$LANG['profiles'][23]="Rezervavimo administravimas"; 
$LANG['profiles'][24]="Atnaujinti slaptažodį"; 
$LANG['profiles'][26]="Mano grupėje sukurtos paraiškos"; 
$LANG['profiles'][27]="See hardware of my group(s)"; 
$LANG['profiles'][28]="Rekursinis"; 
$LANG['profiles'][29]="Dinaminis"; 
$LANG['profiles'][30]="OSCNG info"; 
$LANG['profiles'][31]="Sinchronizuoti su OCSNG rankiniu būdu"; 
$LANG['profiles'][32]="Rodyti priskirtas paraiškas (asmens + susietos grupės)"; 
$LANG['profiles'][33]="Nėra tokio naudotojo"; 
$LANG['profiles'][34]="Išnaša"; 
$LANG['profiles'][35]="Atnaujinti visus nukreipimus"; 
$LANG['profiles'][36]="Mano grupės naudotojų kalendorius"; 
$LANG['profiles'][37]="Numatytasis padalinys"; 
$LANG['profiles'][38]="Matomumas"; 
$LANG['profiles'][39]="Priskyrimas"; 
$LANG['profiles'][40]="Atnaujinti"; 
$LANG['profiles'][41]="Sukūrimas"; 
$LANG['profiles'][42]="Susiejimas"; 
$LANG['profiles'][43]="Tapatybės nustatymo ir sinchronizavimo vartotojams būdas"; 
$LANG['profiles'][44]="Change the priority"; 
$LANG['profiles'][45]="Add a task to all tickets"; 
$LANG['profiles'][46]="Edit all tasks"; 
$LANG['profiles'][47]="Add users from an external source"; 
$LANG['profiles'][48]="Create a validation request"; 
$LANG['profiles'][49]="Validate a ticket"; 

$LANG['registry'][1]="Hive"; 
$LANG['registry'][2]="Kelias"; 
$LANG['registry'][3]="Vardas/reikšmė"; 
$LANG['registry'][4]="Yra toks vardas registre"; 
$LANG['registry'][5]="Nerastas vardas registre"; 
$LANG['registry'][6]="OCSNG name"; 

$LANG['reminder'][0]="Asmeniniai užrašai"; 
$LANG['reminder'][1]="Vieši užrašai"; 
$LANG['reminder'][6]="Nauja pastaba"; 
$LANG['reminder'][9]="Tekstas"; 
$LANG['reminder'][12]="Add to schedule"; 
$LANG['reminder'][15]="Be antraštės"; 
$LANG['reminder'][16]="Bendros pastabos"; 

$LANG['reports'][0]="Išrinkite iš sąrašo norimą ataskaitą"; 
$LANG['reports'][4]="Įrangos sąrašas galiojančiai sutarčiai"; 
$LANG['reports'][11]="Įranga galiojančiai sutarčiai"; 
$LANG['reports'][12]="Įrangos tipas"; 
$LANG['reports'][13]="Data(os)"; 
$LANG['reports'][15]="Rodyti ataskaitas"; 
$LANG['reports'][19]="Alternate username"; 
$LANG['reports'][26]="Įprastinė ataskaita"; 
$LANG['reports'][27]="Pagal sutartis"; 
$LANG['reports'][28]="Pagal metus"; 
$LANG['reports'][33]="Tinklo ataskaita"; 
$LANG['reports'][36]="Prijungti įrenginiai"; 
$LANG['reports'][37]="Atšaukimai"; 
$LANG['reports'][38]="IP"; 
$LANG['reports'][39]="Pagal patalpą"; 
$LANG['reports'][41]="Pagal aparatinę įrangą"; 
$LANG['reports'][42]="Atmesti"; 
$LANG['reports'][46]="aparatūros prievadai"; 
$LANG['reports'][47]="įrenginio prievadai"; 
$LANG['reports'][49]="Tinklo ataskaita pagal aparatūrą"; 
$LANG['reports'][51]="Tinklo ataskaita pagal atmestus"; 
$LANG['reports'][52]="šakotuvas"; 
$LANG['reports'][54]="Tinklo ataskaita pagal patalpas"; 
$LANG['reports'][57]="Medžiagų sąrašas"; 
$LANG['reports'][58]="Equipment's report by year"; 
$LANG['reports'][60]="Pradžios data"; 
$LANG['reports'][61]="Closing date"; 
$LANG['reports'][62]="Įrangos finansinė informacija"; 
$LANG['reports'][63]="Kita finansinė informacija"; 
$LANG['reports'][64]="Resolution date"; 

$LANG['reservation'][1]="Rezervuojami elementai"; 
$LANG['reservation'][2]="Įrenginys laikinai neprienamas"; 
$LANG['reservation'][3]="Make unavailable"; 
$LANG['reservation'][5]="Make available"; 
$LANG['reservation'][6]="Prohibit reservations"; 
$LANG['reservation'][7]="Authorize reservations"; 
$LANG['reservation'][8]="Rezervuoti"; 
$LANG['reservation'][9]="Rezervuoti elementą"; 
$LANG['reservation'][16]="Iki"; 
$LANG['reservation'][17]="Nuo"; 
$LANG['reservation'][18]="Ieškomas elementas yra rezervuotas šiam laiko tarpui"; 
$LANG['reservation'][20]="Back to planning"; 
$LANG['reservation'][21]="See planning"; 
$LANG['reservation'][22]="Pakeisti pastabas"; 
$LANG['reservation'][25]="All reservable hardware"; 
$LANG['reservation'][27]="Priminimas"; 
$LANG['reservation'][28]="Savaitinis"; 
$LANG['reservation'][29]="Dienomis"; 
$LANG['reservation'][30]="kartai"; 
$LANG['reservation'][31]="Pagal"; 
$LANG['reservation'][35]="Būsimos ir vykdomos Rezervacijos"; 
$LANG['reservation'][36]="Rezervacijos praeityje"; 
$LANG['reservation'][37]="Nėra rezervacijų"; 
$LANG['reservation'][38]="Are you sure you want do return this non-reservable item ?"; 
$LANG['reservation'][39]="Bus atšauktos vykdomos rezervacijos"; 
$LANG['reservation'][40]="Material reservations expiring today"; 

$LANG['rulesengine'][0]="yra"; 
$LANG['rulesengine'][1]="nėra"; 
$LANG['rulesengine'][2]="yra"; 
$LANG['rulesengine'][3]="nėra"; 
$LANG['rulesengine'][4]="Prasidedantis"; 
$LANG['rulesengine'][5]="finished by"; 
$LANG['rulesengine'][6]="Kriterijus"; 
$LANG['rulesengine'][7]="Veiksmai"; 
$LANG['rulesengine'][8]="Taisyklių tvarkymas"; 
$LANG['rulesengine'][9]="Loginis operatorius"; 
$LANG['rulesengine'][10]="Position"; 
$LANG['rulesengine'][11]="Veiksmo tipas"; 
$LANG['rulesengine'][12]="Laukai"; 
$LANG['rulesengine'][13]="Reikšmė"; 
$LANG['rulesengine'][14]="Sąlyga"; 
$LANG['rulesengine'][15]="Priežastis"; 
$LANG['rulesengine'][16]="Kriterijus"; 
$LANG['rulesengine'][17]="Taisyklės"; 
$LANG['rulesengine'][18]="Rules for assigning a computer to an entity"; 
$LANG['rulesengine'][19]="Padalinys ir teisių suteikimo taisyklės"; 
$LANG['rulesengine'][20]="Rules applied"; 
$LANG['rulesengine'][21]="Rules applicable in the sub-entities"; 
$LANG['rulesengine'][22]="Priskirti"; 
$LANG['rulesengine'][23]="Local rules"; 
$LANG['rulesengine'][24]="Formulės tipas"; 
$LANG['rulesengine'][25]="Computer's name"; 
$LANG['rulesengine'][26]="regular expression checks"; 
$LANG['rulesengine'][27]="regular expression does not match"; 
$LANG['rulesengine'][28]="Business rules for tickets"; 
$LANG['rulesengine'][29]="sąrašo taisyklės"; 
$LANG['rulesengine'][30]="Veiksmas"; 
$LANG['rulesengine'][33]="Iškleidžiamo sąrašo elementų žodynas"; 
$LANG['rulesengine'][35]="Programinės įrangos žodynas"; 
$LANG['rulesengine'][36]="Gamintojo žodynas"; 
$LANG['rulesengine'][37]="Kategorijų programinei įrangai priskyrimo taisyklės"; 
$LANG['rulesengine'][38]="Perskaičiuoti"; 
$LANG['rulesengine'][40]="kategorija"; 
$LANG['rulesengine'][41]="Patvirtinimas"; 
$LANG['rulesengine'][42]="IR"; 
$LANG['rulesengine'][43]="ARBA"; 
$LANG['rulesengine'][45]="Assign the value from regular expression"; 
$LANG['rulesengine'][46]="Priskyrimas: įrangos IP adresas"; 
$LANG['rulesengine'][47]="Priskyrimas: įrangos pavadinimas + srities vardas"; 
$LANG['rulesengine'][48]="Priskirti įrangą"; 
$LANG['rulesengine'][49]="Priskyrimas: įrangos MAC adresas"; 
$LANG['rulesengine'][50]="Kompiuterio modelio žodynas"; 
$LANG['rulesengine'][51]="Vaizduoklių modelių žodynas"; 
$LANG['rulesengine'][52]="Telefonų modelių žodynas"; 
$LANG['rulesengine'][53]="Išorinių įrenginių žodynas"; 
$LANG['rulesengine'][54]="Spausdintuvų modelių žodynas"; 
$LANG['rulesengine'][55]="Tinklo įrenginių modelių žodynas"; 
$LANG['rulesengine'][56]="Modeliai"; 
$LANG['rulesengine'][60]="Kompiuterių tipų žodynas"; 
$LANG['rulesengine'][61]="Vaizduoklių tipų žodynas"; 
$LANG['rulesengine'][62]="Telefonų tipų žodynas"; 
$LANG['rulesengine'][63]="Išorinių įrenginių tipų žodynas"; 
$LANG['rulesengine'][64]="Spausdintuvų tipų žodynas"; 
$LANG['rulesengine'][65]="Tinklo įrangos tipų žodynas"; 
$LANG['rulesengine'][66]="Tipai"; 
$LANG['rulesengine'][67]="Operating systems dictionary"; 
$LANG['rulesengine'][68]="Pataisų paketų žodynas"; 
$LANG['rulesengine'][69]="OS versijų žodynas"; 
$LANG['rulesengine'][70]="Rules for assigning a ticket created through a mail receiver"; 
$LANG['rulesengine'][76]="Pakartojimų žodynas"; 
$LANG['rulesengine'][77]="Žodynai"; 
$LANG['rulesengine'][78]="Versija"; 
$LANG['rulesengine'][79]="Add the result from regular expression"; 
$LANG['rulesengine'][80]="Bendras žodynas"; 
$LANG['rulesengine'][81]="Formulės rezultatas"; 
$LANG['rulesengine'][82]="Išsamus rezultatas"; 
$LANG['rulesengine'][83]="It is possible to affect the result of a regular expression using the string #0"; 
$LANG['rulesengine'][84]="Tikrinti taisyklių modulį"; 
$LANG['rulesengine'][85]="Result of the regular expression"; 
$LANG['rulesengine'][86]="Softwarecategory affected when software deleted by dictionary"; 
$LANG['rulesengine'][87]="Programinė įranga pašalinta GLPI žodyno pagalba"; 
$LANG['rulesengine'][90]="Užduotis tebevykdoma..."; 
$LANG['rulesengine'][91]="Užduotis atlikta"; 
$LANG['rulesengine'][92]="Perspėti prieš atveriant žodyną"; 
$LANG['rulesengine'][93]="Dėmesio! Šis veiksmas gali pašalinti programinę įrangą. <br> Reiktų perspėti naudotojus."; 
$LANG['rulesengine'][94]="FUSION"; 
$LANG['rulesengine'][95]="Gamintojo pasirinkimas"; 
$LANG['rulesengine'][96]="Atkartoti žodyną gamintojui(ams) <br> (----- = Visi)"; 
$LANG['rulesengine'][97]="Nėra elementų patikrinimui"; 
$LANG['rulesengine'][100]="Podėlio duomenys"; 
$LANG['rulesengine'][102]="Formulės vardas"; 
$LANG['rulesengine'][103]="Objektai podėlyje"; 
$LANG['rulesengine'][104]="Pradinė reikšmė"; 
$LANG['rulesengine'][105]="Pakeista reikšmė"; 
$LANG['rulesengine'][106]="Nepakitęs"; 
$LANG['rulesengine'][107]="Neveiksnus"; 
$LANG['rulesengine'][108]="pradinis"; 
$LANG['rulesengine'][110]="Teisių priskyrimas"; 
$LANG['rulesengine'][111]="Elementų priskyrimas"; 
$LANG['rulesengine'][112]="Teisių ir elementų priskyrimas"; 
$LANG['rulesengine'][120]="Modulis sustos ties pirmąja taisyklės sąlyga"; 
$LANG['rulesengine'][121]="Modulis įtrauks visa taisyklių rinkinį"; 
$LANG['rulesengine'][122]="Modulis perduos taisyklės rezultatą šiems elementams"; 
$LANG['rulesengine'][130]="Entity from LDAP"; 
$LANG['rulesengine'][131]="Entity from TAG"; 
$LANG['rulesengine'][132]="To be unaware of import"; 
$LANG['rulesengine'][133]="Entity from domain"; 
$LANG['rulesengine'][134]="Reject email (without email response)"; 
$LANG['rulesengine'][135]="Reject email (with email response)"; 
$LANG['rulesengine'][138]="LDAP criterias"; 
$LANG['rulesengine'][140]="Add a criterium"; 
$LANG['rulesengine'][142]="List of not imported emails"; 
$LANG['rulesengine'][144]="Entity based on user's profile"; 
$LANG['rulesengine'][145]="User with a single profile"; 
$LANG['rulesengine'][146]="User featuring the profile"; 
$LANG['rulesengine'][147]="User featuring a single profile"; 
$LANG['rulesengine'][148]="Mail domain is known"; 
$LANG['rulesengine'][150]="The rules linked with the entity have been disabled."; 

$LANG['search'][0]="Paieška"; 
$LANG['search'][1]="for all"; 
$LANG['search'][2]="talpina"; 
$LANG['search'][4]="rikiuoti pagal"; 
$LANG['search'][8]="Pradžios data"; 
$LANG['search'][9]="Pabaigos data"; 
$LANG['search'][10]="kur"; 
$LANG['search'][11]="Matomi elementai"; 
$LANG['search'][12]="Indicate an ended date"; 
$LANG['search'][15]="Nieko nerasta"; 
$LANG['search'][16]="paskutinis"; 
$LANG['search'][17]="Pridėti paieškos kriterijų"; 
$LANG['search'][18]="Pašalinti paieškos kriterijų"; 
$LANG['search'][19]="Pridėti visuotinės paieškos kriterijų"; 
$LANG['search'][20]="Pridėti visuotinės paieškos kriterijų"; 

$LANG['setup'][0]="Sudedamosios"; 
$LANG['setup'][2]="Pridėti naudotoją..."; 
$LANG['setup'][3]="LDAP directory link"; 
$LANG['setup'][4]="Kompiuterių tipai"; 
$LANG['setup'][5]="Operacinės sistemos"; 
$LANG['setup'][6]="Papildomi"; 
$LANG['setup'][9]="Tinklo sąsajos"; 
$LANG['setup'][10]="Display order of surnames firstnames"; 
$LANG['setup'][14]="Email"; 
$LANG['setup'][18]="Prisijungimas"; 
$LANG['setup'][19]="Slaptažodis"; 
$LANG['setup'][20]="Password confirmation"; 
$LANG['setup'][21]="Error : the two passwords are not identical"; 
$LANG['setup'][35]="MHz"; 
$LANG['setup'][39]="Followed private for default"; 
$LANG['setup'][40]="Private tasks by default"; 
$LANG['setup'][41]="Pasirinkti kalbą"; 
$LANG['setup'][42]="Tinklo Tipai"; 
$LANG['setup'][43]="Spausdintuvų tipai"; 
$LANG['setup'][44]="Vaizduoklių Tipai"; 
$LANG['setup'][45]="Korpuso tipas"; 
$LANG['setup'][46]="Default value"; 
$LANG['setup'][47]="Default chart format"; 
$LANG['setup'][48]="Default values"; 
$LANG['setup'][62]="Pasirinkti kategoriją konfiguravimui"; 
$LANG['setup'][63]="Tai gali pašalinti antraštę vienam ar keliems iš elementų"; 
$LANG['setup'][64]="If you confirm the deletion the items using this heading used fields will be blanked"; 
$LANG['setup'][65]="Galima pakeisti taip tituluojamus įvykius kitu:"; 
$LANG['setup'][67]="Išorinis tapatybės nustatymas"; 
$LANG['setup'][69]="Įrangos tipai"; 
$LANG['setup'][70]="Bendra sąranka"; 
$LANG['setup'][71]="Programuojama įranga"; 
$LANG['setup'][73]="Tinklo elementas"; 
$LANG['setup'][74]="Negalima pašalinti šios patalpos, nes yra jai priklausančių"; 
$LANG['setup'][75]="kaip atšaka"; 
$LANG['setup'][79]="Paraiškų kategorijos"; 
$LANG['setup'][80]="Trečiųjų šalių Tipas"; 
$LANG['setup'][81]="Dokumento antraštės"; 
$LANG['setup'][82]="Kontaktų Tipas"; 
$LANG['setup'][83]="Elemento būsena"; 
$LANG['setup'][84]="Kasetės tipas"; 
$LANG['setup'][85]="Sutarties Tipas"; 
$LANG['setup'][86]="Type of memory"; 
$LANG['setup'][87]="Knowledge base categories"; 
$LANG['setup'][88]="Tinklas"; 
$LANG['setup'][89]="Sritis (domenas)"; 
$LANG['setup'][90]="VLAN"; 
$LANG['setup'][91]="Kompiuterių Modeliai"; 
$LANG['setup'][92]="Medžiagų tipai"; 
$LANG['setup'][93]="Kietojo disko sąsajos"; 
$LANG['setup'][94]="Vaizduoklių Modeliai"; 
$LANG['setup'][95]="Tinklo įrangos modeliai"; 
$LANG['setup'][96]="Spausdintuvų modeliai"; 
$LANG['setup'][97]="Išorinių įrenginių Modeliai"; 
$LANG['setup'][98]="Tasks category"; 
$LANG['setup'][99]="Building number"; 
$LANG['setup'][100]="Room number"; 
$LANG['setup'][101]="Maximal number of automatic actions (run by CLI)"; 
$LANG['setup'][102]="Įrašų lygis"; 
$LANG['setup'][103]="1 - Kritinis (tik prisijungimo klaidos)"; 
$LANG['setup'][104]="2 - Kiti (Nenaudojamas)"; 
$LANG['setup'][105]="3- Svarbus (įvykę prisijungimai)"; 
$LANG['setup'][106]="4- Pastabos (Pridėti, pašalinti, sekti)"; 
$LANG['setup'][107]="5- Pilnas (Viską)"; 
$LANG['setup'][109]="How long system logs are keep in database (in days, 0 for infinite)"; 
$LANG['setup'][110]="Prisijungus rodyti naujas paraiškas"; 
$LANG['setup'][111]="Maximum number of search results to display on a page"; 
$LANG['setup'][112]="Maximum number of characters for each items in dropdowns"; 
$LANG['setup'][113]="Numatytoji kalba"; 
$LANG['setup'][114]="Prioritetinės spalvos"; 
$LANG['setup'][115]="Numatytoji riba kasetėms ir medžiagų kiekiui"; 
$LANG['setup'][116]="Priskirti paraiškas techniniam darbuotojui automatiškai"; 
$LANG['setup'][117]="Autorizuoti DUK anoniminę peržiūrą"; 
$LANG['setup'][118]="Prisijungimo puslapio tekstas"; 
$LANG['setup'][119]="Display"; 
$LANG['setup'][120]="Use dynamic display for dropdowns and text fields"; 
$LANG['setup'][121]="Character to force the full display of dropdowns (wildcard)"; 
$LANG['setup'][122]="Maximum number of items to display in the dropdowns when wildcard is not used"; 
$LANG['setup'][123]="Don't use dynamic display if the number of items is less than"; 
$LANG['setup'][124]="Pridėti išorinio tapatybės nustatymo naudotojus automatiškai"; 
$LANG['setup'][125]="... Iš išorinio šaltinio"; 
$LANG['setup'][126]="Pridėti išorinio šaltinio vartotoją automatiškai"; 
$LANG['setup'][127]="Autocompletion of text fields"; 
$LANG['setup'][128]="Datos Formatas"; 
$LANG['setup'][129]="Show GLPI ID"; 
$LANG['setup'][130]="Number of days this action logs are stored"; 
$LANG['setup'][132]="Display the complete name in the tree dropdowns"; 
$LANG['setup'][133]="Aktyvuoti OCSNG"; 
$LANG['setup'][134]="OCS NG Veiksena"; 
$LANG['setup'][135]="Normalus"; 
$LANG['setup'][136]="Vertimas"; 
$LANG['setup'][137]="Derinimas"; 
$LANG['setup'][138]="GLPI veiksena"; 
$LANG['setup'][139]="Bendras"; 
$LANG['setup'][140]="Tipai"; 
$LANG['setup'][145]="Os"; 
$LANG['setup'][147]="Dynamic display"; 
$LANG['setup'][148]="Žingsnis valandoms"; 
$LANG['setup'][149]="Vietos po kablelio sumose"; 
$LANG['setup'][150]="Skaičiaus Formatas"; 
$LANG['setup'][154]="Bazinis dn"; 
$LANG['setup'][155]="rootdn (neanoniminiams sujungimams)"; 
$LANG['setup'][156]="Slaptažodis (neautentikuotiems sujungimams)"; 
$LANG['setup'][157]="Neįdiegtas PHP preprocesoriaus LDAP plėtinys"; 
$LANG['setup'][158]="Nesudarytos sąlygos naudoti LDAP kaip išorinį prisijungimo šaltinį"; 
$LANG['setup'][159]="Prisijungimo filtras"; 
$LANG['setup'][162]="IMAP/POP sąranka"; 
$LANG['setup'][164]="IMAP/POP stoties vardas <br> (naudotojo pašto adresą sudarys login@stoties_vardas)"; 
$LANG['setup'][165]="PHP preprocesorius įdiegtas be IMAP palaikymo"; 
$LANG['setup'][166]="Nesudarytos galimybės naudoti IMAP/POP kaip išorinį prisijungimo šaltinį"; 
$LANG['setup'][167]="LDAP directory / GLPI links"; 
$LANG['setup'][168]="Prijungimo parinktys"; 
$LANG['setup'][169]="Pašto aplankas (neprivalomas, dažniausiai INBOX)"; 
$LANG['setup'][170]="Connection string"; 
$LANG['setup'][171]="Prievadas (nebūtinas)"; 
$LANG['setup'][172]="Port (default=389)"; 
$LANG['setup'][174]="CAS Stotis"; 
$LANG['setup'][175]="Prievadas"; 
$LANG['setup'][176]="Šakninis aplankas (nebūtinas)"; 
$LANG['setup'][177]="CAS sąranka"; 
$LANG['setup'][178]="PHP preprocesoriaus CURL arba DOMXML plėtiniai neįdiegti"; 
$LANG['setup'][179]="Neįmanoma naudoti CAS kaip išorinį prisijungimo šaltinį"; 
$LANG['setup'][180]="Naudoti TLS"; 
$LANG['setup'][181]="ldap_start_tls nerastas"; 
$LANG['setup'][182]="Logout fallback URL"; 
$LANG['setup'][185]="Logs in files (SQL, email, automatic action...)"; 
$LANG['setup'][186]="Laiko juosta"; 
$LANG['setup'][190]="x509 certifikatas"; 
$LANG['setup'][191]="x509 pašto atributai"; 
$LANG['setup'][192]="Įjungtas"; 
$LANG['setup'][193]="Laukas talpinantis prisijungimus _SERVER masyve"; 
$LANG['setup'][194]="Additional informations retrieval from LDAP directory"; 
$LANG['setup'][195]="Tęsti būseną"; 
$LANG['setup'][196]="Clear status"; 
$LANG['setup'][197]="Kopijuoti kompiuterio būseną"; 
$LANG['setup'][198]="Nustatyti būseną"; 
$LANG['setup'][199]="Remove the domain of login in form login@domain"; 
$LANG['setup'][200]="Infinite"; 
$LANG['setup'][201]="Alert and email followups configuration"; 
$LANG['setup'][202]="Enable Follow-up via email"; 
$LANG['setup'][203]="Administratoriaus e-pašto adresas"; 
$LANG['setup'][204]="E-laiško parašas"; 
$LANG['setup'][205]="Laiškas išsiūstas administratoriui"; 
$LANG['setup'][206]="Nepavyko išsiūsti laiško tvarkytojui"; 
$LANG['setup'][207]="Atsakyti administratoriui šiuo adresu (jei reikalinga)"; 
$LANG['setup'][217]="Neveiksni PHP pašto funkcija arba neaktyvuota"; 
$LANG['setup'][218]="Reikalingas SMTP naudojimas"; 
$LANG['setup'][219]="Allow anonymous ticket creation (helpdesk.receiver)"; 
$LANG['setup'][221]="Beginning of fiscal year"; 
$LANG['setup'][223]="Dienų skaičiaus riba planavimui"; 
$LANG['setup'][227]="URL of the application"; 
$LANG['setup'][228]="Prisijungimo Laukas"; 
$LANG['setup'][229]="Send a test email to the administrator"; 
$LANG['setup'][231]="Naudoti SMTP stotį pašto išsiuntimui"; 
$LANG['setup'][232]="SMTP Host"; 
$LANG['setup'][234]="SMTP prisijungimas (neprivalomas)"; 
$LANG['setup'][235]="SMTP slaptažodis (neprivalomas)"; 
$LANG['setup'][236]="Ankstesnis paraišką vykdęs technikas"; 
$LANG['setup'][237]="Administratorius"; 
$LANG['setup'][239]="Už paraišką atsakingas technikas"; 
$LANG['setup'][240]="Pranešimų parinktys"; 
$LANG['setup'][241]="Nėra išskirtinių kriterijų. Sukurti asmeninius parametrus?"; 
$LANG['setup'][242]="Įspėjimai"; 
$LANG['setup'][243]="Įspėjimai dėl medžiagų"; 
$LANG['setup'][244]="Įspėjimai dėl kasečių"; 
$LANG['setup'][245]="Reminders frequency"; 
$LANG['setup'][246]="Įspėjimai dėl sutarčių"; 
$LANG['setup'][247]="Įspėjimai dėl finansinių duomenų"; 
$LANG['setup'][248]="Grupė atsakinga už paraišką"; 
$LANG['setup'][249]="Pareiškėjo grupė"; 
$LANG['setup'][250]="Paieškos lauko sąrašas pagal nutylėjimą"; 
$LANG['setup'][252]="Pasirinkti numatytuosius rodymui elementus"; 
$LANG['setup'][253]="Paieška pagal grupes"; 
$LANG['setup'][254]="Paieškos tipas"; 
$LANG['setup'][255]="Grupės naudotojai"; 
$LANG['setup'][256]="Tarp naudotojų"; 
$LANG['setup'][257]="Grupėse"; 
$LANG['setup'][258]="Naudotojai ir Grupės"; 
$LANG['setup'][259]="Priklausantis grupėms"; 
$LANG['setup'][260]="Naudotojo grupę nusakanti savybė"; 
$LANG['setup'][261]="Grupės DN"; 
$LANG['setup'][262]="Naudoti DN paieškoje"; 
$LANG['setup'][263]="Naudotojo filtras paieškai"; 
$LANG['setup'][264]="Įspėjimai dėl nebegaliojančių licencijų"; 
$LANG['setup'][271]="Apriboti vaizduoklio tvarkymą"; 
$LANG['setup'][272]="Apriboti įrenginio tvarkymą"; 
$LANG['setup'][273]="Apriboti telefono tvarkymą"; 
$LANG['setup'][274]="pridėti ranka"; 
$LANG['setup'][275]="Apriboti spausdintuvo tvarkymą"; 
$LANG['setup'][280]="Automatically update of the elements related to the computers"; 
$LANG['setup'][281]="When connecting or updating"; 
$LANG['setup'][282]="When disconnecting"; 
$LANG['setup'][283]="Kopijuoti"; 
$LANG['setup'][284]="Išvalyti"; 
$LANG['setup'][285]="Do not copy"; 
$LANG['setup'][286]="Do not delete"; 
$LANG['setup'][300]="Tikrinti, ar yra naujesnė versija"; 
$LANG['setup'][301]="Yra atnaujinimas"; 
$LANG['setup'][302]="Jūs tai surasite glpi-project.org svetainėje."; 
$LANG['setup'][303]="Ši versija yra naujausia"; 
$LANG['setup'][304]="Nepavyko prisijungti."; 
$LANG['setup'][305]="Kasdien"; 
$LANG['setup'][306]="Ar yra naujinimų"; 
$LANG['setup'][307]="Niekada"; 
$LANG['setup'][308]="Kas savaitę"; 
$LANG['setup'][309]="Kas mėnesį"; 
$LANG['setup'][310]="Neįmanoma prisijungti prie svetainės"; 
$LANG['setup'][311]="Nepavyko prisijungti prie tarpinės stoties"; 
$LANG['setup'][312]="Tinklavietė neprienama"; 
$LANG['setup'][313]="Be careful : there is no default value"; 
$LANG['setup'][350]="Ryšys su elementais paraiškos sudarymui"; 
$LANG['setup'][351]="Visi elementai"; 
$LANG['setup'][352]="Susiję elementai paraiškoje"; 
$LANG['setup'][360]="Programuojami laukai (su žyme *)"; 
$LANG['setup'][400]="Proxy configuration"; 
$LANG['setup'][407]="Simplified interface help link"; 
$LANG['setup'][408]="Standard interface help link"; 
$LANG['setup'][409]="Numatytoji antraštė pridedant dokumentą paraiškai"; 
$LANG['setup'][503]="Telefonų modeliai"; 
$LANG['setup'][504]="Telefonų Tipai"; 
$LANG['setup'][505]="Telefonų maitinimo blokų tipas"; 
$LANG['setup'][601]="LDAP reikšmė"; 
$LANG['setup'][602]="Prisijungimas prie OCSNG duomenų bazės"; 
$LANG['setup'][603]="Įtraukti naudotoją"; 
$LANG['setup'][604]="Susieti su grupe"; 
$LANG['setup'][606]="Nepavyko pridėti. Toks naudotojas jau yra."; 
$LANG['setup'][607]="Susieti su profiliu"; 
$LANG['setup'][608]="Software associable to a ticket by default"; 
$LANG['setup'][609]="Unable to add. The OCSNG server already exists."; 
$LANG['setup'][610]="Paraiškos antraštė (compulsory)"; 
$LANG['setup'][611]="'Compulsory' paraiškos turinys"; 
$LANG['setup'][612]="[Compulsory?] paraiškų kategorijos"; 
$LANG['setup'][613]="Add a user who have no accreditation from a LDAP directory"; 
$LANG['setup'][614]="Prisijungimo vardo pakeitimas negalimas. Naudotojas tokiu vardu jau yra."; 
$LANG['setup'][615]="Life cycle of tickets"; 
$LANG['setup'][616]="From \ To"; 
$LANG['setup'][620]="Saitas"; 
$LANG['setup'][621]="Search filter for entities"; 
$LANG['setup'][622]="Attribute representing entity"; 
$LANG['setup'][623]="Import entities from LDAP directory"; 
$LANG['setup'][650]="PHP"; 
$LANG['setup'][651]="SMTP"; 
$LANG['setup'][652]="SMTP+SSL"; 
$LANG['setup'][653]="SMTP+TLS"; 
$LANG['setup'][660]="Mail server"; 
$LANG['setup'][661]="Impossible to configure the notifications : please enable email monitoring"; 
$LANG['setup'][703]="Bendri"; 
$LANG['setup'][704]="Pranešimai"; 
$LANG['setup'][707]="Alerts on reservations"; 
$LANG['setup'][708]="Alerts on tickets which are not solved since"; 
$LANG['setup'][720]="System informations"; 
$LANG['setup'][721]="Information about system installation and configuration"; 
$LANG['setup'][722]="To copy/paste in your support request"; 
$LANG['setup'][731]="Value of the global configuration"; 
$LANG['setup'][732]="Domain of electronic mail service"; 
$LANG['setup'][800]="Mysql kopijavimas"; 
$LANG['setup'][801]="Enable the MySQL replicate"; 
$LANG['setup'][802]="Duomenų bazė"; 
$LANG['setup'][803]="Skirtumas tarp vedančio ir vedamojo"; 
$LANG['setup'][806]="Max delay between master and slave (minutes)"; 
$LANG['setup'][807]="The slave base is desynchronized. The difference is of:"; 
$LANG['setup'][808]="Vedamoji duomenų bazė nesinchronizuota"; 
$LANG['setup'][809]="MySQL rezervinė kopija: tik skaitymui"; 
$LANG['setup'][810]="Desynchronization MySQL replication"; 

$LANG['software'][1]="Purchase version"; 
$LANG['software'][2]="Version in use"; 
$LANG['software'][3]="Not installed affected licenses"; 
$LANG['software'][4]="Unlimited"; 
$LANG['software'][5]="Versijos"; 
$LANG['software'][6]="Publisher"; 
$LANG['software'][7]="Pridėti versiją"; 
$LANG['software'][8]="Pridėti licenziją"; 
$LANG['software'][11]="Licencijos"; 
$LANG['software'][17]="Įdiegta programinė įranga"; 
$LANG['software'][19]="Įdiegimai"; 
$LANG['software'][20]="Likusi"; 
$LANG['software'][28]="OEM"; 
$LANG['software'][29]="Atnaujinti"; 
$LANG['software'][30]="Type of license"; 
$LANG['software'][32]="Galioja iki"; 
$LANG['software'][44]="Įdiegti įrangą"; 
$LANG['software'][45]="Išdiegti įrangą"; 
$LANG['software'][46]="Associable to a ticket"; 
$LANG['software'][47]="Merging"; 
$LANG['software'][48]="Merge"; 
$LANG['software'][49]="Software deleted after merging"; 
$LANG['software'][50]="Priskirta kompiuteriui"; 
$LANG['software'][51]="The number must be 1 to be able to affect"; 

$LANG['softwarecategories'][2]="Uncategorized software"; 
$LANG['softwarecategories'][3]="Unfold the software without category"; 
$LANG['softwarecategories'][4]="Unfold the software belonging to a category"; 
$LANG['softwarecategories'][5]="Programinės įrangos kategorija"; 

$LANG['state'][0]="Būsena"; 
$LANG['state'][6]="Elemento tipas"; 
$LANG['state'][7]="Nėra elementų"; 
$LANG['state'][11]="Suvestinė"; 

$LANG['stats'][0]="Pasirinkite suvestinės tipą"; 
$LANG['stats'][1]="Visiems"; 
$LANG['stats'][2]="No item to display"; 
$LANG['stats'][3]="Elementui"; 
$LANG['stats'][5]="Number of opened tickets"; 
$LANG['stats'][6]="Atsakymo užlaikymas (vidutinis)"; 
$LANG['stats'][7]="Show graphics"; 
$LANG['stats'][11]="Įvykdytų paraiškų skaičius"; 
$LANG['stats'][13]="Paraiškų skaičius"; 
$LANG['stats'][15]="Atsakymo užlaikymas (vidutinis)"; 
$LANG['stats'][16]="Techniko vardas"; 
$LANG['stats'][20]="Naudotojo vardas"; 
$LANG['stats'][23]="Nėra duomenų suvestinei"; 
$LANG['stats'][25]="Paraiškos vykdymo trukmė"; 
$LANG['stats'][27]="Pilnas laikas paraiškai"; 
$LANG['stats'][30]="Laikas iki atsakymo į paraišką"; 
$LANG['stats'][31]="Diena(os)"; 
$LANG['stats'][33]="Minutė(s)"; 
$LANG['stats'][34]="Sekundė(s)"; 
$LANG['stats'][35]="Paraiška(os)"; 
$LANG['stats'][44]="Tiekėjo vardas"; 
$LANG['stats'][45]="Pagal techninę įrangą"; 
$LANG['stats'][47]="Pagal paraiškas"; 
$LANG['stats'][48]="(priskirti)"; 
$LANG['stats'][49]="(teikiniai)"; 

$LANG['title'][5]="Žinynas"; 
$LANG['title'][6]="Tinklas"; 
$LANG['title'][9]="Elemento būsena"; 
$LANG['title'][10]="Paraiškos vykdymo eiga"; 
$LANG['title'][13]="Duomenys apie naudotoją"; 
$LANG['title'][14]="Išoriniai tapatybės nustatymo šaltiniai"; 
$LANG['title'][24]="Pagalba"; 
$LANG['title'][26]="Pagrindinis"; 
$LANG['title'][27]="Sujungimai"; 
$LANG['title'][28]="Paraiškos"; 
$LANG['title'][30]="Komponentai"; 
$LANG['title'][33]="Išorinės nuorodos"; 
$LANG['title'][34]="Nuorodos"; 
$LANG['title'][37]="Pastabos"; 
$LANG['title'][38]="Istoriškai"; 
$LANG['title'][40]="Viešos ir asmeninės pastabos"; 
$LANG['title'][42]="Masinis keitimas"; 
$LANG['title'][43]="Registras"; 

$LANG['tracking'][1]="Mano įrenginiai"; 
$LANG['tracking'][2]="Išsami paieška"; 
$LANG['tracking'][3]="Netinkamos datos. Keitimas atšauktas"; 
$LANG['tracking'][4]="There is no urgency in your ticket, please correct."; 
$LANG['tracking'][8]="Jūsų paraiškoje nėra aprašymo, ištaisykite."; 
$LANG['tracking'][9]="Default for tickets"; 
$LANG['tracking'][10]="Default for mail recipients"; 
$LANG['tracking'][24]="Paraiškos dokumentas"; 
$LANG['tracking'][29]="Skaičius"; 
$LANG['tracking'][30]="Nauji"; 
$LANG['tracking'][31]="Eigoje (priskirti)"; 
$LANG['tracking'][32]="Eigoje (suplanuoti)"; 
$LANG['tracking'][34]="Tiesioginis"; 
$LANG['tracking'][35]="Raštu"; 
$LANG['tracking'][37]="Išsaugoti paraiškas elemento pašalinimui iš inventoriaus"; 
$LANG['tracking'][38]="Laiškas išsiūstas"; 
$LANG['tracking'][39]="Visible in the simplified interface"; 

$LANG['transfer'][1]="Perkėlimas"; 
$LANG['transfer'][3]="Jei nėra naudojamas"; 
$LANG['transfer'][4]="Perkeliamų elementų sąrašo išvalymas"; 
$LANG['transfer'][5]="Galite tęsti pridėdami elementus perkėlimui arba perkelti šiuos elementus"; 
$LANG['transfer'][6]="Prieš perkeliant elementus patartina sukurti atsarginę kopiją"; 
$LANG['transfer'][7]="Elementai perkėlimui"; 
$LANG['transfer'][8]="Perkėlimo būdas"; 

$LANG['update'][88]="Netinkama duomenų bazės versija. Būtinas atnaujinimas."; 
$LANG['update'][89]="Ši GLPI versija skirta aukštesnei duomenų bazės versijai, nei esanti. Įdiekite versiją atitinkančią jūsų duomenų bazę."; 
$LANG['update'][90]="Klaida atnaujinant duomenų bazę"; 
$LANG['update'][91]="Dėmesio!"; 
$LANG['update'][92]="Atnaujinsite GLPI duomenų bazę, vardu :"; 
$LANG['update'][93]="Prisijungimas prie tos pačios duomenų bazės"; 
$LANG['update'][94]="Atnaujinimas sėkmingai įvykdytas."; 
$LANG['update'][95]="Klaida jungiantis prie duomenų bazės, patikrinkite prisijungimo parametrus config_db.php rinkmenoje"; 
$LANG['update'][96]="Administratoriams suteiktos 'super-admin' teisės. Pridėtas naujas naudotojo profilis."; 
$LANG['update'][105]="Nėra galimybės šiuo būdų užbaigti atnaujinimo"; 
$LANG['update'][106]="Atgal į GLPI"; 
$LANG['update'][107]="Toliau bus atnaujinamos duomenų bazės įrašų reiškmės"; 
$LANG['update'][130]="Patalpų atnaujinimas"; 
$LANG['update'][131]="Nauja struktūra yra hierarchinė"; 
$LANG['update'][132]="Naudojant skyriklį, galite juo generuoti naujus hierarchinius ryšius"; 
$LANG['update'][133]="Taip pat reikia apibrėžti pradinio lygmnems patalpą, kuriai priklausys visos kitos patalpos"; 
$LANG['update'][134]="Skyriklis"; 
$LANG['update'][135]="Pagrindinio lygmens patalpa"; 
$LANG['update'][136]="Tai nauja hierarchija. Jei ji tinkama, galite ją patvirtinti"; 
$LANG['update'][137]="Nauja hierarchija"; 
$LANG['update'][138]="Esamos patalpos"; 
$LANG['update'][139]="Lentelių optimizavimas"; 
$LANG['update'][140]="Creating indexes"; 
$LANG['update'][141]="Change of the database layout"; 
$LANG['update'][142]="Data migration"; 

$LANG['users'][1]="Kreipinys"; 
$LANG['users'][2]="Kategorija"; 

$LANG['validation'][0]="Approval"; 
$LANG['validation'][1]="Send a Approval request"; 
$LANG['validation'][2]="Status"; 
$LANG['validation'][3]="Request date"; 
$LANG['validation'][4]="Approval date"; 
$LANG['validation'][5]="Request comment"; 
$LANG['validation'][6]="Approval comment"; 
$LANG['validation'][7]="Approval(s) for the ticket"; 
$LANG['validation'][9]="Waiting for approval"; 
$LANG['validation'][10]="Refused"; 
$LANG['validation'][11]="Granted"; 
$LANG['validation'][12]="Not subject to approval"; 
$LANG['validation'][13]="Approval request send to"; 
$LANG['validation'][15]="Ticket waiting for your Approval"; 
$LANG['validation'][16]="Optional when approved"; 
$LANG['validation'][18]="Approval requester"; 
$LANG['validation'][19]="Approval granted"; 
$LANG['validation'][20]="Approval denied"; 
$LANG['validation'][21]="Approver"; 
$LANG['validation'][23]="The selected user has no valid emailaddress. The request has been created, without email confirmation."; 
$LANG['validation'][26]="Approval request"; 
$LANG['validation'][27]="An approval request has been submitted"; 
$LANG['validation'][28]="Status of the Approval request"; 
$LANG['validation'][29]="If approval is denied, specify a reason"; 
$LANG['validation'][30]="Cancel the approval request to"; 
$LANG['validation'][31]="Update the Approval request to"; 
$LANG['validation'][32]="An answer to a Approval request was produced"; 
$LANG['validation'][33]="Tickets awaiting approval"; 
?>